@@ -244,11 +244,11 @@ inline bool EncoderBase::CheckBuffer(
 {
   bool r = true;
   if (n > static_cast<size_t>(ep - cp))
-    {
+  {
     r = vtkDICOMCompilerInternalFriendship::FlushBuffer(
           this->Compiler, cp, ep);
     r &= (n <= static_cast<size_t>(ep - cp));
-    }
+  }
   return r;
 }
 
@@ -260,36 +260,36 @@ unsigned int EncoderBase::DataSize(
   unsigned int l = 0;
 
   while (iter != iterEnd)
-    {
+  {
     const vtkDICOMValue &v = iter->GetValue(this->Index);
     vtkDICOMVR vr = v.GetVR();
     unsigned int vl = v.GetVL();
 
     if (vr == vtkDICOMVR::SQ)
-      {
+    {
       size_t n = v.GetNumberOfValues();
       const vtkDICOMItem *ptr = v.GetSequenceData();
       for (size_t i = 0; i < n && vl != HxFFFFFFFF; i++)
-        {
+      {
         unsigned int ll = this->DataSize(ptr[i].Begin(), ptr[i].End());
         // check for overflow or ll == 0xffffffff
         if (HxFFFFFFFF - vl <= ll || HxFFFFFFFF - vl - ll <= 8)
-          {
+        {
           vl = HxFFFFFFFF;
-          }
+        }
         else
-          {
+        {
           vl += ll + 8;
-          }
         }
       }
+    }
 
     // terminate if length is unknown
     if (vl == HxFFFFFFFF)
-      {
+    {
       l = vl;
       break;
-      }
+    }
 
     // force vl to even
     assert((vl & 1) == 0);
@@ -298,14 +298,14 @@ unsigned int EncoderBase::DataSize(
     unsigned int hl = (this->ImplicitVR || !vr.HasLongVL() ? 8 : 12);
     // check for overflow
     if (HxFFFFFFFF - l <= vl || HxFFFFFFFF - l - vl <= hl)
-      {
+    {
       l = HxFFFFFFFF;
       break;
-      }
+    }
     l += vl + hl;
 
     ++iter;
-    }
+  }
 
   return l;
 }
@@ -422,12 +422,12 @@ void Encoder<E>::PutValues(
   union { float f; unsigned int i; } u;
 
   do
-    {
+  {
     u.f = *ip;
     Encoder<E>::PutInt32(op, u.i);
     ip++;
     op += 4;
-    }
+  }
   while (--n);
 }
 
@@ -438,12 +438,12 @@ void Encoder<E>::PutValues(
   union { double d; unsigned long long l; } u;
 
   do
-    {
+  {
     u.d = *ip;
     Encoder<E>::PutInt64(op, u.l);
     ip++;
     op += 8;
-    }
+  }
   while (--n);
 }
 
@@ -452,12 +452,12 @@ void Encoder<E>::PutValues(
   unsigned char *op, const vtkDICOMTag *ip, size_t n)
 {
   do
-    {
+  {
     Encoder<E>::PutInt16(op, ip->GetGroup());
     Encoder<E>::PutInt16(op+2, ip->GetElement());
     ip++;
     op += 4;
-    }
+  }
   while (--n);
 }
 
@@ -469,14 +469,14 @@ bool Encoder<E>::WriteData(
   unsigned char* &cp, unsigned char* &ep, const T *ptr, size_t n)
 {
   while (n != 0 && this->CheckBuffer(cp, ep, sizeof(T)))
-    {
+  {
     size_t m = (ep - cp)/sizeof(T);
     if (m > n) { m = n; }
     Encoder<E>::PutValues(cp, ptr, m);
     cp += m*sizeof(T);
     ptr += m;
     n -= m;
-    }
+  }
 
   return (n == 0);
 }
@@ -494,18 +494,18 @@ size_t Encoder<E>::WriteElementHead(
   cp[5] = vrt[1];
   Encoder<E>::PutInt16(cp+6, static_cast<unsigned short>(vl));
   if (this->ImplicitVR)
-    {
+  {
     Encoder<E>::PutInt32(cp+4, vl);
-    }
+  }
   else if (vr.HasLongVL())
-    {
+  {
     hl = 12;
     cp[6] = 0;
     cp[7] = 0;
     Encoder<E>::PutInt32(cp+8, vl);
-    }
+  }
   else if (vl > 65534)
-    {
+  {
     // CP-1066 allows overlength values to be written as UN
     hl = 12;
     cp[4] = 'U';
@@ -513,7 +513,7 @@ size_t Encoder<E>::WriteElementHead(
     cp[6] = 0;
     cp[7] = 0;
     Encoder<E>::PutInt32(cp+8, vl);
-    }
+  }
   return hl;
 }
 
@@ -530,15 +530,15 @@ bool Encoder<E>::WriteDataElement(
 
   // do not write invalid values
   if (!v.IsValid())
-    {
+  {
     return true;
-    }
+  }
 
   // handle elements of unknown length
   if (vl == HxFFFFFFFF)
-    {
+  {
     if (vr == vtkDICOMVR::UN || vr == vtkDICOMVR::OB)
-      {
+    {
       // if VR is UN then it is a sequence encoded as implicit LE
       // (see DICOM Part 5, Section 6.2.2, Unknown (UN) Value Representation)
       // if VR is OB then it is a sequence of fragments
@@ -553,137 +553,137 @@ bool Encoder<E>::WriteDataElement(
       assert(ptr[n-4] + (ptr[n-3] << 8) +
              (ptr[n-2] << 16) + (ptr[n-1] << 24) == 0);
 #endif
-      }
+    }
     else if (vr != vtkDICOMVR::SQ)
-      {
+    {
       // only UN, OB, and SQ can have unknown length
       vtkDICOMCompilerInternalFriendship::CompileError(
         this->Compiler, "Illegal item length 0xFFFFFFFF encountered.");
       return false;
-      }
     }
+  }
   else if (vr == vtkDICOMVR::SQ)
-    {
+  {
     // compute the true vl for the sequence
     size_t n = v.GetNumberOfValues();
     const vtkDICOMItem *ptr = v.GetSequenceData();
     for (size_t i = 0; i < n && vl != HxFFFFFFFF; i++)
-      {
+    {
       unsigned int ll = this->DataSize(ptr[i].Begin(), ptr[i].End());
       // check for overflow or ll == 0xffffffff
       if (HxFFFFFFFF - vl <= ll || HxFFFFFFFF - vl - ll <= 8)
-        {
+      {
         vl = HxFFFFFFFF;
-        }
+      }
       else
-        {
+      {
         vl += ll + 8;
-        }
       }
     }
+  }
   else
-    {
+  {
     // vl must be even
     assert((vl & 1) == 0);
     vl += (vl & 1);
-    }
+  }
 
   // write the data element head (tag, vr, vl)
   if (!this->CheckBuffer(cp, ep, 12))
-    {
+  {
     return false;
-    }
+  }
   cp += this->Encoder<E>::WriteElementHead(cp, tag, vr, vl);
 
   // write the value
   bool r = true;
   switch (vr.GetType())
-    {
+  {
     case VTK_CHAR:
-      {
+    {
       const char *ptr = v.GetCharData();
       r = this->WriteData(cp, ep, ptr, vl);
-      }
       break;
+    }
     case VTK_UNSIGNED_CHAR:
-      {
+    {
       size_t n = vl;
       if (vl == HxFFFFFFFF)
-        {
+      {
         n = v.GetNumberOfValues();
         n += (n & 1);
-        }
+      }
       const unsigned char *ptr = v.GetUnsignedCharData();
       r = this->WriteData(cp, ep, ptr, n);
-      }
       break;
+    }
     case VTK_SHORT:
-      {
+    {
       size_t n = vl/sizeof(short);
       const short *ptr = v.GetShortData();
       r = this->WriteData(cp, ep, ptr, n);
-      }
       break;
+    }
     case VTK_UNSIGNED_SHORT:
-      {
+    {
       size_t n = vl/sizeof(unsigned short);
       const unsigned short *ptr = v.GetUnsignedShortData();
       r = this->WriteData(cp, ep, ptr, n);
-      }
       break;
+    }
     case VTK_INT:
-      {
+    {
       size_t n = vl/sizeof(int);
       const int *ptr = v.GetIntData();
       r = this->WriteData(cp, ep, ptr, n);
-      }
       break;
+    }
     case VTK_UNSIGNED_INT:
-      {
+    {
       size_t n = vl/sizeof(unsigned int);
       const unsigned int *ptr = v.GetUnsignedIntData();
       r = this->WriteData(cp, ep, ptr, n);
-      }
       break;
+    }
     case VTK_FLOAT:
-      {
+    {
       size_t n = vl/sizeof(float);
       const float *ptr = v.GetFloatData();
       r = this->WriteData(cp, ep, ptr, n);
-      }
       break;
+    }
     case VTK_DOUBLE:
-      {
+    {
       size_t n = vl/sizeof(double);
       const double *ptr = v.GetDoubleData();
       r = this->WriteData(cp, ep, ptr, n);
-      }
       break;
+    }
     case VTK_DICOM_TAG:
-      {
+    {
       size_t n = vl/sizeof(vtkDICOMTag);
       const vtkDICOMTag *ptr = v.GetTagData();
       r = this->WriteData(cp, ep, ptr, n);
-      }
       break;
+    }
     case VTK_DICOM_ITEM:
-      {
+    {
       size_t n = v.GetNumberOfValues();
       const vtkDICOMItem *ptr = v.GetSequenceData();
 
       for (size_t i = 0; i < n && r; i++)
-        {
+      {
         unsigned int il = 0xFFFFFFFF;
         if (!ptr[i].IsDelimited())
-          {
+        {
           // compute the bytes in the item
           il = this->DataSize(ptr[i].Begin(), ptr[i].End());
-          }
+        }
 
         if ((r = this->CheckBuffer(cp, ep, 8)) == false)
-          {
+        {
           break;
-          }
+        }
         // item start
         Encoder<E>::PutInt16(cp, HxFFFE);
         Encoder<E>::PutInt16(cp+2, HxE000);
@@ -695,33 +695,33 @@ bool Encoder<E>::WriteDataElement(
         this->Depth--;
 
         if (il == HxFFFFFFFF && r)
-          {
+        {
           if ((r = this->CheckBuffer(cp, ep, 8)) == false)
-            {
+          {
             break;
-            }
+          }
           // item delimiter
           Encoder<E>::PutInt16(cp, HxFFFE);
           Encoder<E>::PutInt16(cp+2, HxE00D);
           Encoder<E>::PutInt32(cp+4, 0);
           cp += 8;
-          }
         }
+      }
 
       if (vl == HxFFFFFFFF && r)
-        {
+      {
         if ((r = this->CheckBuffer(cp, ep, 8)) != false)
-          {
+        {
           // sequence delimiter
           Encoder<E>::PutInt16(cp, HxFFFE);
           Encoder<E>::PutInt16(cp+2, HxE0DD);
           Encoder<E>::PutInt32(cp+4, 0);
           cp += 8;
-          }
         }
       }
       break;
     }
+  }
 
   return r;
 }
@@ -734,37 +734,37 @@ bool Encoder<E>::WriteElements(
   vtkDICOMDataElementIterator iterEnd)
 {
   while (iter != iterEnd)
-    {
+  {
     // check for group length tag and length-to-end tag
     if (iter->GetTag().GetElement() == Hx0000 ||
         iter->GetTag() == vtkDICOMTag(0x0008, 0x0001))
-      {
+    {
       unsigned short group = iter->GetTag().GetGroup();
       unsigned int groupLength = HxFFFFFFFF;
       vtkDICOMDataElementIterator groupEnd = iter;
       if (iter->GetTag().GetElement() == Hx0000)
-        {
+      {
         groupEnd = ++iter;
         while (groupEnd != iterEnd && groupEnd->GetTag().GetGroup() == group)
-          {
+        {
           ++groupEnd;
-          }
-        groupLength = this->DataSize(iter, groupEnd);
         }
+        groupLength = this->DataSize(iter, groupEnd);
+      }
       // check for retired LengthToEnd tag
       unsigned int lengthToEnd = HxFFFFFFFF;
       bool hadLengthToEnd = false;
       if (group == 0x0008 && iter != iterEnd &&
           iter->GetTag() == vtkDICOMTag(0x0008, 0x0001))
-        {
+      {
         hadLengthToEnd = true;
         lengthToEnd = this->DataSize(++iter, iterEnd);
-        }
+      }
       // check for uncounted PixelData element size in 0x7FE0 group
       if (this->Depth == 0 &&
           ((groupLength != HxFFFFFFFF && group == 0x7FE0 &&
             iterEnd == groupEnd) || lengthToEnd != HxFFFFFFFF))
-        {
+      {
         // add the size of the missing PixelData element
         unsigned int pl =
           vtkDICOMCompilerInternalFriendship::ComputePixelDataSize(
@@ -773,80 +773,80 @@ bool Encoder<E>::WriteElements(
         // check for overflow of lengthToEnd
         if (HxFFFFFFFF - lengthToEnd <= pl ||
             HxFFFFFFFF - lengthToEnd - pl <= hl)
-          {
+        {
           lengthToEnd = HxFFFFFFFF;
-          }
+        }
         else
-          {
+        {
           lengthToEnd += pl + hl;
-          }
+        }
         // check for overflow of groupLength
         if (group == 0x7FE0)
-          {
+        {
           if (HxFFFFFFFF - groupLength <= pl ||
               HxFFFFFFFF - groupLength - pl <= hl)
-            {
+          {
             groupLength = HxFFFFFFFF;
-            }
+          }
           else
-            {
+          {
             groupLength += pl + hl;
-            }
           }
         }
+      }
       if (groupLength != HxFFFFFFFF)
-        {
+      {
         // subtract the size of LengthToEnd element if it is invalid
         if (lengthToEnd == HxFFFFFFFF && hadLengthToEnd)
-          {
+        {
           groupLength -= 12;
-          }
+        }
         // write out group length with correct value
         this->WriteDataElement(cp, ep,
           vtkDICOMDataElement(vtkDICOMTag(group, 0x0000),
             vtkDICOMValue(vtkDICOMVR::UL, groupLength)));
-        }
+      }
       if (lengthToEnd != HxFFFFFFFF)
-        {
+      {
         // write out LengthToEnd with correct value
         this->WriteDataElement(cp, ep,
           vtkDICOMDataElement(vtkDICOMTag(0x0008, 0x0001),
             vtkDICOMValue(vtkDICOMVR::UL, lengthToEnd)));
-        }
       }
+    }
     else if (this->Depth == 0 && this->SOPInstanceUID &&
              iter->GetTag() == vtkDICOMTag(DC::SOPInstanceUID))
-      {
+    {
       this->WriteDataElement(cp, ep,
         vtkDICOMDataElement(
           vtkDICOMTag(DC::SOPInstanceUID),
           vtkDICOMValue(vtkDICOMVR::UI, this->SOPInstanceUID)));
       ++iter;
-      }
+    }
     else if (this->Depth == 0 && this->SeriesInstanceUID &&
              iter->GetTag() == vtkDICOMTag(DC::SeriesInstanceUID))
-      {
+    {
       this->WriteDataElement(cp, ep,
         vtkDICOMDataElement(
           vtkDICOMTag(DC::SeriesInstanceUID),
           vtkDICOMValue(vtkDICOMVR::UI, this->SeriesInstanceUID)));
       ++iter;
-      }
+    }
     else if (this->Depth == 0 && this->StudyInstanceUID &&
              iter->GetTag() == vtkDICOMTag(DC::StudyInstanceUID))
-      {
+    {
       this->WriteDataElement(cp, ep,
         vtkDICOMDataElement(
           vtkDICOMTag(DC::StudyInstanceUID),
           vtkDICOMValue(vtkDICOMVR::UI, this->StudyInstanceUID)));
       ++iter;
-      }
+    }
     else
-      {
+    {
       this->WriteDataElement(cp, ep, *iter);
       ++iter;
-      }
     }
+  }
 
   return true;
 }
@@ -915,59 +915,52 @@ vtkDICOMCompiler::~vtkDICOMCompiler()
   delete [] this->TransferSyntaxUID;
 
   if (this->MetaData)
-    {
+  {
     this->MetaData->Delete();
-    }
+  }
   if (this->SeriesUIDs)
-    {
+  {
     this->SeriesUIDs->Delete();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMCompiler::SetBufferSize(int size)
 {
   if (size < 256)
-    {
+  {
     size = 256;
-    }
+  }
   if (size > (2147483647 - 8))
-    {
+  {
     size = (2147483647 - 8);
-    }
+  }
 
   if (this->BufferSize != size)
-    {
+  {
     this->BufferSize = size;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMCompiler::GenerateSeriesUIDs()
 {
   if (this->SeriesUIDs == 0)
-    {
+  {
     this->SeriesUIDs = vtkStringArray::New();
-    }
+  }
 
   this->SeriesUIDs->Initialize();
   if (this->MetaData)
-    {
+  {
     int n = this->MetaData->GetNumberOfInstances();
     this->SeriesUIDs->SetNumberOfValues(n + 1); // allocate n+1
     this->SeriesUIDs->SetNumberOfValues(n); // but set to n values
     vtkDICOMUtilities::GenerateUIDs(DC::SOPInstanceUID, this->SeriesUIDs);
     this->SeriesUIDs->InsertNextValue(
       vtkDICOMUtilities::GenerateUID(DC::SeriesInstanceUID));
-    }
-
-  // study UID is only generated once per session
-  if (vtkDICOMCompiler::StudyUID[0] == '\0')
-    {
-    std::string uid = vtkDICOMUtilities::GenerateUID(DC::StudyInstanceUID);
-    strcpy(vtkDICOMCompiler::StudyUID, uid.c_str());
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -981,33 +974,33 @@ void vtkDICOMCompiler::WriteHeader()
 void vtkDICOMCompiler::Close()
 {
   if (this->Compressed && this->FrameCounter > 0)
-    {
+  {
     this->WriteFragments();
-    }
+  }
 
   if (this->OutputFile)
-    {
+  {
     this->OutputFile->Close();
     delete this->OutputFile;
     this->OutputFile = NULL;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMCompiler::CloseAndRemove()
 {
   if (this->Compressed && this->FrameCounter > 0)
-    {
+  {
     this->FreeFragments();
-    }
+  }
 
   if (this->OutputFile)
-    {
+  {
     this->OutputFile->Close();
     delete this->OutputFile;
     this->OutputFile = NULL;
     vtkDICOMFile::Remove(this->FileName);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1016,7 +1009,7 @@ bool vtkDICOMCompiler::WriteFragments()
   bool fileError = false;
 
   if (this->OutputFile && this->ErrorCode == 0)
-    {
+  {
     // Compressed frames
     unsigned int numFrames = this->FrameCounter;
     size_t n = 0;
@@ -1034,30 +1027,30 @@ bool vtkDICOMCompiler::WriteFragments()
     const unsigned int maxOffset = HxFFFFFFFF - 1;
     unsigned int offset = 0;
     for (unsigned int i = 0; i < numFrames; i++)
-      {
+    {
       Encoder<LE>::PutInt32(buffer + 8 + i*4, offset);
       // make sure offsets don't exceed 32-bit limit
       if (maxOffset - offset >= this->FrameLength[i])
-        {
+      {
         offset += this->FrameLength[i];
-        }
+      }
       else
-        {
+      {
         tableLength = 0;
         vtkDICOMUtilities::PackUnsignedInt(tableLength, buffer + 4);
         break;
-        }
       }
+    }
 
     // write the offset table to the file
     n = this->OutputFile->Write(buffer, tableLength + 8);
     if (n < tableLength + 8)
-      {
+    {
       fileError = true;
-      }
+    }
 
     for (unsigned int i = 0; i < numFrames && !fileError; i++)
-      {
+    {
       // Fragment value header
       // - Item tag (FFFE, E000)
       // - Length of item in bytes (4 bytes)
@@ -1066,23 +1059,23 @@ bool vtkDICOMCompiler::WriteFragments()
       Encoder<LE>::PutInt32(buffer+4, this->FrameLength[i]);
       n = this->OutputFile->Write(buffer, 8);
       if (n < 8)
-        {
+      {
         fileError = true;
         break;
-        }
+      }
 
       // - Fragment data
       assert((this->FrameLength[i] & 1) == 0);
       n = this->OutputFile->Write(this->FrameData[i], this->FrameLength[i]);
       if (n < this->FrameLength[i])
-        {
+      {
         fileError = true;
         break;
-        }
       }
+    }
 
     if (!fileError)
-      {
+    {
       // After final fragment:
       // - Sequence delimiter tag (FFFE, E0DD)
       // - Zero length
@@ -1091,20 +1084,20 @@ bool vtkDICOMCompiler::WriteFragments()
       Encoder<LE>::PutInt32(buffer+4, 0);
       n = this->OutputFile->Write(buffer, 8);
       if (n < 8)
-        {
+      {
         fileError = true;
-        }
       }
+    }
 
     delete [] buffer;
-    }
+  }
 
   this->FreeFragments();
 
   if (fileError)
-    {
+  {
     this->DiskFullError();
-    }
+  }
 
   return !fileError;
 }
@@ -1114,9 +1107,9 @@ void vtkDICOMCompiler::FreeFragments()
 {
   unsigned int numFrames = this->FrameCounter;
   for (unsigned int i = 0; i < numFrames; i++)
-    {
+  {
     delete [] this->FrameData[i];
-    }
+  }
   delete [] this->FrameData;
   delete [] this->FrameLength;
   this->FrameData = 0;
@@ -1128,39 +1121,40 @@ bool vtkDICOMCompiler::WriteFile(vtkDICOMMetaData *data, int idx)
 {
   // Check that the file name has been set.
   if (!this->FileName)
-    {
+  {
     this->SetErrorCode(vtkErrorCode::NoFileNameError);
     vtkErrorMacro("WriteFile: No file name has been set");
     return false;
-    }
+  }
 
   // Generate fresh UIDs if at index zero
-  if (idx == 0 || this->SeriesUIDs == 0 ||
-      this->SeriesUIDs->GetNumberOfValues() !=
-      data->GetNumberOfInstances() + 1)
-    {
+  if ((this->SOPInstanceUID == 0 || this->SeriesInstanceUID == 0) &&
+      (idx == 0 || this->SeriesUIDs == 0 ||
+       this->SeriesUIDs->GetNumberOfValues() !=
+       data->GetNumberOfInstances() + 1))
+  {
     this->GenerateSeriesUIDs();
-    }
+  }
 
   this->OutputFile = new vtkDICOMFile(this->FileName, vtkDICOMFile::Out);
 
   if (this->OutputFile->GetError())
-    {
+  {
     this->SetErrorCode(vtkErrorCode::CannotOpenFileError);
     const char *errText = "Can't open the file ";
     if (this->OutputFile->GetError() == vtkDICOMFile::AccessDenied)
-      {
+    {
       errText = "No permission to write the file ";
-      }
+    }
     else if (this->OutputFile->GetError() == vtkDICOMFile::FileIsDirectory)
-      {
+    {
       errText = "The selected file is a directory ";
-      }
+    }
     delete this->OutputFile;
     this->OutputFile = 0;
     vtkErrorMacro("WriteFile: " << errText << this->FileName);
     return false;
-    }
+  }
 
   this->Buffer = new unsigned char [this->BufferSize];
   // guard against anyone changing BufferSize while compiling the file
@@ -1174,7 +1168,7 @@ bool vtkDICOMCompiler::WriteFile(vtkDICOMMetaData *data, int idx)
 
   // only write preamble and meta header if transfer syntax is set
   if (this->TransferSyntaxUID != 0)
-    {
+  {
     // write the preamble
     memset(cp, '\0', 128);
     cp += 128;
@@ -1185,30 +1179,30 @@ bool vtkDICOMCompiler::WriteFile(vtkDICOMMetaData *data, int idx)
     cp += 4;
 
     r = this->WriteMetaHeader(cp, ep, data, idx);
-    }
+  }
   if (r)
-    {
+  {
     r = this->WriteMetaData(cp, ep, data, idx);
-    }
+  }
   if (r)
-    {
+  {
     r = this->FlushBuffer(cp, ep);
-    }
+  }
 
   delete [] this->Buffer;
 
   // delete the file if an error occurred
   if (!r)
-    {
+  {
     if (this->GetErrorCode() == vtkErrorCode::NoError)
-      {
+    {
       this->DiskFullError();
-      }
-    else
-      {
-      this->CloseAndRemove();
-      }
     }
+    else
+    {
+      this->CloseAndRemove();
+    }
+  }
 
   return r;
 }
@@ -1217,24 +1211,24 @@ bool vtkDICOMCompiler::WriteFile(vtkDICOMMetaData *data, int idx)
 void vtkDICOMCompiler::WritePixelData(const unsigned char *cp, vtkIdType size)
 {
   if (this->OutputFile == 0)
-    {
+  {
     return;
-    }
+  }
 
   size_t n = this->OutputFile->Write(cp, size);
   if (n != static_cast<size_t>(size))
-    {
+  {
     this->DiskFullError();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMCompiler::WriteFrame(const unsigned char *cp, vtkIdType size)
 {
   if (this->OutputFile == 0)
-    {
+  {
     return;
-    }
+  }
 
   union { char c[2]; short s; } endiancheck;
   // this will set endiancheck.s to 1 on little endian architectures
@@ -1243,21 +1237,21 @@ void vtkDICOMCompiler::WriteFrame(const unsigned char *cp, vtkIdType size)
   size_t n = 0;
 
   if (this->Compressed)
-    {
+  {
     // if this is the first frame, do some set-up
     if (this->FrameCounter == 0)
-      {
+    {
       unsigned int numFrames =
         this->MetaData->GetAttributeValue(DC::NumberOfFrames).AsUnsignedInt();
       numFrames = (numFrames == 0 ? 1 : numFrames);
       this->FrameData = new unsigned char *[numFrames];
       this->FrameLength = new unsigned int[numFrames];
       for (unsigned int i = 0; i < numFrames; i++)
-        {
+      {
         this->FrameData[i] = 0;
         this->FrameLength[i] = 0;
-        }
       }
+    }
 
     vtkDICOMImageCodec codec(this->TransferSyntaxUID);
     size_t fl = 0;
@@ -1267,48 +1261,48 @@ void vtkDICOMCompiler::WriteFrame(const unsigned char *cp, vtkIdType size)
     this->FrameData[this->FrameCounter] = fd;
 
     if (this->ErrorCode == 0 && errCode != vtkDICOMImageCodec::NoError)
-      {
+    {
       this->SetErrorCode(vtkErrorCode::FileFormatError);
       vtkErrorMacro("Writing compressed DICOM is not supported.");
-      }
+    }
 
     // mark all data as accepted
     n = size;
-    }
+  }
   else if (((this->BigEndian != 0) ^ (endiancheck.s != 1)) &&
            this->MetaData->GetAttributeValue(DC::BitsAllocated).AsInt() > 8)
-    {
+  {
     // Swap bytes before writing
     int scalarSize =
       (this->MetaData->GetAttributeValue(DC::BitsAllocated).AsInt() + 7)/8;
     unsigned char *buf = new unsigned char[size];
     unsigned char *dp = buf;
     if (scalarSize == 2)
-      {
+    {
       for (vtkIdType i = 0; i < size; i += 2)
-        {
+      {
         dp[0] = cp[1];
         dp[1] = cp[0];
         dp += 2;
         cp += 2;
-        }
       }
+    }
     else if (scalarSize == 4)
-      {
+    {
       for (vtkIdType i = 0; i < size; i += 4)
-        {
+      {
         dp[0] = cp[3];
         dp[1] = cp[2];
         dp[2] = cp[1];
         dp[3] = cp[0];
         dp += 4;
         cp += 4;
-        }
       }
+    }
     else if (scalarSize == 8)
-      {
+    {
       for (vtkIdType i = 0; i < size; i += 8)
-        {
+      {
         dp[0] = cp[7];
         dp[1] = cp[6];
         dp[2] = cp[5];
@@ -1319,21 +1313,21 @@ void vtkDICOMCompiler::WriteFrame(const unsigned char *cp, vtkIdType size)
         dp[7] = cp[0];
         dp += 8;
         cp += 8;
-        }
       }
+    }
     n = this->OutputFile->Write(buf, size);
     delete [] buf;
-    }
+  }
   else
-    {
+  {
     // For uncompressed frames, write the data raw
     n = this->OutputFile->Write(cp, size);
-    }
+  }
 
   if (n != static_cast<size_t>(size))
-    {
+  {
     this->DiskFullError();
-    }
+  }
 
   this->FrameCounter++;
 }
@@ -1345,9 +1339,9 @@ bool vtkDICOMCompiler::WriteMetaHeader(
 {
   // if no transfer syntax is set, do not write header
   if (this->TransferSyntaxUID == 0)
-    {
+  {
     return true;
-    }
+  }
 
   // create the encoder
   LittleEndianEncoder encoder(this, idx);
@@ -1361,22 +1355,22 @@ bool vtkDICOMCompiler::WriteMetaHeader(
   std::string classUIDString =
     meta->GetAttributeValue(DC::SOPClassUID).AsString();
   if (classUIDString == "")
-    {
+  {
     // if not present (e.g. DICOMDIR) get it from the meta header
     classUIDString =
       meta->GetAttributeValue(DC::MediaStorageSOPClassUID).AsString();
-    }
+  }
   const char *classUID = classUIDString.c_str();
 
   if (instanceUID == 0)
-    {
+  {
     instanceUID = this->SeriesUIDs->GetValue(idx);
-    }
+  }
   if (implementationUID == 0)
-    {
+  {
     implementationUID =
       vtkDICOMUtilities::GetImplementationClassUID();
-    }
+  }
 
   vtkDICOMItem item;
   item.SetAttributeValue(
@@ -1399,38 +1393,38 @@ bool vtkDICOMCompiler::WriteMetaHeader(
     vtkDICOMValue(vtkDICOMVR::UI, implementationUID));
 
   if (this->ImplementationVersionName)
-    {
+  {
     item.SetAttributeValue(
       DC::ImplementationVersionName,
       vtkDICOMValue(vtkDICOMVR::SH,
                     this->ImplementationVersionName));
-    }
+  }
 
   if (this->SourceApplicationEntityTitle)
-    {
+  {
     item.SetAttributeValue(
       DC::SourceApplicationEntityTitle,
       vtkDICOMValue(vtkDICOMVR::AE,
                     this->SourceApplicationEntityTitle));
-    }
+  }
 
   // keep private information stored in meta header
   const char *creatorUID =
     meta->GetAttributeValue(DC::PrivateInformationCreatorUID).GetCharData();
   if (creatorUID)
-    {
+  {
     item.SetAttributeValue(DC::PrivateInformationCreatorUID, creatorUID);
     item.SetAttributeValue(DC::PrivateInformation,
       meta->GetAttributeValue(DC::PrivateInformation));
-    }
+  }
 
   vtkDICOMDataElementIterator iter = item.Begin();
   vtkDICOMDataElementIterator iterEnd = item.End();
 
   if (iter != iterEnd)
-    {
+  {
     encoder.WriteElements(cp, ep, iter, iterEnd);
-    }
+  }
 
   return true;
 }
@@ -1453,41 +1447,47 @@ bool vtkDICOMCompiler::WriteMetaData(
   if (tsyntax == "" || // If no meta header, use Implicit LE
       tsyntax == "1.2.840.10008.1.2" ||  // Implicit LE
       tsyntax == "1.2.840.10008.1.20")   // Papyrus Implicit LE
-    {
+  {
     encoder->SetImplicitVR(true);
-    }
+  }
   else if (tsyntax == "1.2.840.10008.1.2.2") // Explicit BE
-    {
+  {
     encoder = &encoderBE;
     this->BigEndian = true;
-    }
+  }
   else if (tsyntax == "1.2.840.113619.5.2")  // GE LE with BE data
-    {
+  {
     encoder->SetImplicitVR(true);
     this->BigEndian = true;
-    }
+  }
   else if (tsyntax != "1.2.840.10008.1.2.1") // Explicit LE
-    {
+  {
     this->Compressed = true;
-    }
+  }
 
   const char *instanceUID = this->SOPInstanceUID;
   const char *seriesUID = this->SeriesInstanceUID;
   const char *studyUID = this->StudyInstanceUID;
 
   if (instanceUID == 0)
-    {
+  {
     instanceUID = this->SeriesUIDs->GetValue(idx);
-    }
+  }
   if (seriesUID == 0)
-    {
+  {
     seriesUID = this->SeriesUIDs->GetValue(this->SeriesUIDs->GetMaxId());
-    }
+  }
   if (studyUID == 0 &&
       meta->GetAttributeValue(DC::StudyInstanceUID).AsString() == "")
+  {
+    // study UID is only generated once per session
+    if (vtkDICOMCompiler::StudyUID[0] == '\0')
     {
-    studyUID = vtkDICOMCompiler::StudyUID;
+      std::string uid = vtkDICOMUtilities::GenerateUID(DC::StudyInstanceUID);
+      strcpy(vtkDICOMCompiler::StudyUID, uid.c_str());
     }
+    studyUID = vtkDICOMCompiler::StudyUID;
+  }
 
   encoder->SetSOPInstanceUID(instanceUID);
   encoder->SetSeriesInstanceUID(seriesUID);
@@ -1498,22 +1498,22 @@ bool vtkDICOMCompiler::WriteMetaData(
 
   // skip past the meta header
   while (iter != iterEnd && iter->GetTag().GetGroup() <= 0x0002)
-    {
+  {
     ++iter;
-    }
+  }
 
   // if last element is PixelData, don't write it yet
   bool hasPixelData = false;
   if (iterEnd != iter)
-    {
+  {
     vtkDICOMDataElementIterator finalElement = iterEnd;
     --finalElement;
     if (finalElement->GetTag() == vtkDICOMTag(DC::PixelData))
-      {
+    {
       iterEnd = finalElement;
       hasPixelData = true;
-      }
     }
+  }
 
   // write the meta data, get boolean status value
   bool r = encoder->WriteElements(cp, ep, iter, iterEnd);
@@ -1521,24 +1521,24 @@ bool vtkDICOMCompiler::WriteMetaData(
   // write the PixelData element head
   if (r && hasPixelData &&
       (r = encoder->CheckBuffer(cp, ep, 12)) != false)
-    {
+  {
     vtkDICOMVR vr = vtkDICOMVR::OW;
     int bitsAllocated = this->MetaData->GetAttributeValue(
       DC::BitsAllocated).AsInt();
     if ((bitsAllocated > 0 && bitsAllocated <= 8) || this->Compressed)
-      {
+    {
       vr = vtkDICOMVR::OB;
-      }
+    }
 
     if (this->KeepOriginalPixelDataVR)
-      {
+    {
       vtkDICOMVR vrOriginal = this->MetaData->GetAttributeValue(
         idx, DC::PixelData).GetVR();
       if (vrOriginal.IsValid())
-        {
+      {
         vr = vrOriginal;
-        }
       }
+    }
 
     unsigned int vl = this->ComputePixelDataSize();
 
@@ -1546,7 +1546,7 @@ bool vtkDICOMCompiler::WriteMetaData(
     size_t l = encoder->WriteElementHead(
       cp, vtkDICOMTag(DC::PixelData), vr, vl);
     cp += l;
-    }
+  }
 
   return r;
 }
@@ -1556,13 +1556,13 @@ unsigned int vtkDICOMCompiler::ComputePixelDataSize()
 {
   unsigned int vl = HxFFFFFFFF;
   if (!this->Compressed)
-    {
+  {
     // compute the size
     vtkDICOMMetaData *meta = this->MetaData;
     int bitsAllocated = meta->GetAttributeValue(
       this->Index, DC::BitsAllocated).AsInt();
     if (bitsAllocated > 0)
-      {
+    {
       vl = meta->GetAttributeValue(
         this->Index, DC::Columns).AsUnsignedInt();
       vl *= meta->GetAttributeValue(
@@ -1574,17 +1574,17 @@ unsigned int vtkDICOMCompiler::ComputePixelDataSize()
       vl *= ((m > 1) ? m : 1);
       vl *= ((n > 1) ? n : 1);
       if (bitsAllocated % 8 == 0)
-        {
+      {
         vl *= bitsAllocated/8;
-        }
+      }
       else
-        {
+      {
         // this will only occur in ancient data
         vl = (vl*bitsAllocated + 7)/8;
         vl += (vl & 1); // make it even
-        }
       }
     }
+  }
 
   return vl;
 }
@@ -1600,11 +1600,11 @@ bool vtkDICOMCompiler::FlushBuffer(
   ep = dp + this->ChunkSize;
 
   if (cp)
-    {
+  {
     size_t n = cp - dp;
     size_t m = this->OutputFile->Write(dp, n);
     rval = (n == m);
-    }
+  }
 
   return rval;
 }
