@@ -44,8 +44,8 @@ public:
   //@{
   //! Set the input directory.
   /*!
-   *  Set the input directory.  If it has a DICOMDIR file, then that
-   *  file will be scanned to get info about the directory.  Otherwise,
+   *  If the directory has a DICOMDIR file, then that file will be scanned
+   *  to get information about the DICOM files in the directory.  Otherwise,
    *  the directory will be scanned for DICOM files.  The depth of the
    *  scan (how many subdirectories deep) can be controlled with the
    *  SetScanDepth() method.
@@ -61,6 +61,15 @@ public:
    */
   void SetInputFileNames(vtkStringArray *sa);
   vtkStringArray *GetInputFileNames() { return this->InputFileNames; }
+
+  //! Add more filenames to be read.
+  /*!
+   *  This allows the directory to be updated.  The new files can belong to
+   *  an existing series or a new series.  If any of the new files are
+   *  already present in the directory, then nothing will be done for those
+   *  files.
+   */
+  void AddInputFileNames(vtkStringArray *sa);
   //@}
 
   //@{
@@ -197,6 +206,17 @@ public:
   int GetFollowSymlinks() { return this->FollowSymlinks; }
   //@}
 
+  //@{
+  //! If On (the default), hidden files will be listed.
+  /*!
+   *  A file is hidden if it has a "hidden" attribute set.  On Linux and
+   *  OS X, any file that begins with "." will also be considered "hidden".
+   */
+  vtkSetMacro(ShowHidden, int);
+  vtkBooleanMacro(ShowHidden, int);
+  int GetShowHidden() { return this->ShowHidden; }
+  //@}
+
 protected:
   vtkDICOMDirectory();
   ~vtkDICOMDirectory();
@@ -206,6 +226,7 @@ protected:
   const char *FilePattern;
   int RequirePixelData;
   int FollowSymlinks;
+  int ShowHidden;
   int ScanDepth;
 
   vtkTimeStamp UpdateTime;
@@ -300,8 +321,8 @@ protected:
     vtkDICOMMetaData *meta, const vtkDICOMItem *item, int instance);
 
 private:
-  vtkDICOMDirectory(const vtkDICOMDirectory&);  // Not implemented.
-  void operator=(const vtkDICOMDirectory&);  // Not implemented.
+  vtkDICOMDirectory(const vtkDICOMDirectory&) VTK_DELETE_FUNCTION;
+  void operator=(const vtkDICOMDirectory&) VTK_DELETE_FUNCTION;
 
   struct SeriesItem;
   struct StudyItem;
