@@ -43,6 +43,9 @@ public:
    */
   vtkDICOMFileDirectory(const char *dirname);
 
+  //! Copy constructor.
+  vtkDICOMFileDirectory(const vtkDICOMFileDirectory&);
+
   //! Destruct the object.
   ~vtkDICOMFileDirectory();
   //@}
@@ -64,6 +67,9 @@ public:
 
   //! Check if the list entry is a symbolic link.
   bool IsSymlink(int i);
+
+  //! Check if the list entry has an attribute that marks it as hidden.
+  bool IsHidden(int i);
   //@}
 
   //@{
@@ -76,13 +82,22 @@ public:
   static int Create(const char *dirname);
   //@}
 
+  //@{
+  //! Assignment operator.
+  vtkDICOMFileDirectory& operator=(const vtkDICOMFileDirectory&);
+  //@}
+
 private:
   //! Add a directory entry.
   void AddEntry(const char *name, unsigned short flags, unsigned short mask);
 
+  //! Stat a file to set flags
+  void StatEntry(int i);
+
   struct Entry;
   static const unsigned int TypeDirectory = 1;
   static const unsigned int TypeSymlink = 2;
+  static const unsigned int TypeHidden = 4;
 
   std::string Name;
   int Error;
