@@ -39,6 +39,9 @@ public:
   vtkDICOMFilePath(const std::wstring& path);
 #endif
 
+  //! Copy constructor.
+  vtkDICOMFilePath(const vtkDICOMFilePath&);
+
   //! Destructor.
   ~vtkDICOMFilePath();
   //@}
@@ -120,6 +123,11 @@ public:
 
 #endif
 
+  //@{
+  //! Assignment operator.
+  vtkDICOMFilePath& operator=(const vtkDICOMFilePath&);
+  //@}
+
 private:
 
   //! Check if the given character is a separator.
