@@ -60,7 +60,8 @@ struct vtkDICOMFileSorter::FileInfo
   std::string FileName;
   vtkDICOMValue StudyUID;
   vtkDICOMValue SeriesUID;
-  int InstanceNumber;
+  vtkDICOMValue InstanceUID;
+  unsigned int InstanceNumber;
 };
 
 bool vtkDICOMFileSorter::CompareInstance(
@@ -95,17 +96,17 @@ vtkDICOMFileSorter::vtkDICOMFileSorter()
 vtkDICOMFileSorter::~vtkDICOMFileSorter()
 {
   if (this->InputFileName)
-    {
+  {
     delete [] this->InputFileName;
-    }
+  }
   if (this->InputFileNames)
-    {
+  {
     this->InputFileNames->Delete();
-    }
+  }
   if (this->InternalFileName)
-    {
+  {
     delete [] this->InternalFileName;
-    }
+  }
 
   this->OutputFileNames->Delete();
   delete this->Series;
@@ -139,18 +140,18 @@ void vtkDICOMFileSorter::SetInputFileName(const char *name)
   if (name == this->InputFileName ||
       (name && this->InputFileName &&
        strcmp(name, this->InputFileName) == 0))
-    {
+  {
     return;
-    }
+  }
 
   delete [] this->InputFileName;
   this->InputFileName = 0;
   if (name)
-    {
+  {
     char *cp = new char[strlen(name) + 1];
     strcpy(cp, name);
     this->InputFileName = cp;
-    }
+  }
   this->Modified();
 }
 
@@ -203,21 +204,21 @@ void vtkDICOMFileSorter::AddSeriesFileNames(int study, vtkStringArray *files)
   vtkIdType n = this->Studies->GetNumberOfTuples();
   int st[2];
   if (study == n)
-    {
+  {
     st[0] = static_cast<int>(this->Series->size());
     st[1] = st[0];
     this->Studies->InsertNextTupleValue(st);
-    }
+  }
   else if (n >= 0 && study == n-1)
-    {
+  {
     this->Studies->GetTupleValue(study, st);
     st[1]++;
     this->Studies->SetTupleValue(study, st);
-    }
+  }
   else
-    {
+  {
     vtkErrorMacro("AddSeriesFileNames: non-monotonically increasing study")
-    }
+  }
 
   this->Series->push_back(files);
 }
@@ -235,6 +236,7 @@ void vtkDICOMFileSorter::SortFiles(vtkStringArray *input)
   parser->AddObserver(
     vtkCommand::ErrorEvent, this, &vtkDICOMFileSorter::RelayError);
 
+  groups->InsertNextValue(0x0008);
   groups->InsertNextValue(0x0020);
   parser->SetMetaData(meta);
   parser->SetGroups(groups);
@@ -244,35 +246,35 @@ void vtkDICOMFileSorter::SortFiles(vtkStringArray *input)
 
   vtkIdType numberOfStrings = input->GetNumberOfValues();
   for (vtkIdType j = 0; j < numberOfStrings; j++)
-    {
+  {
     const std::string& fileName = input->GetValue(j);
     this->SetInternalFileName(fileName.c_str());
 
     int code = vtkDICOMFile::Access(fileName.c_str(), vtkDICOMFile::In);
     if (code == vtkDICOMFile::FileIsDirectory)
-      {
+    {
       // Skip anything that is a directory
       continue;
-      }
+    }
     else if (code != 0)
-      {
+    {
       const char *errText = "Can't open the file ";
       this->SetErrorCode(vtkErrorCode::CannotOpenFileError);
       if (code == vtkDICOMFile::AccessDenied)
-        {
+      {
         errText = "No permission to read the file ";
-        }
+      }
       else if (code == vtkDICOMFile::FileNotFound)
-        {
+      {
         errText = "File not found ";
-        }
+      }
       else if (code == vtkDICOMFile::ImpossiblePath)
-        {
+      {
         errText = "Bad file path ";
-        }
+      }
       vtkErrorMacro("SortFiles: " << errText << this->InternalFileName);
       continue;
-      }
+    }
 
     // Read the file metadata
     meta->Initialize();
@@ -280,22 +282,23 @@ void vtkDICOMFileSorter::SortFiles(vtkStringArray *input)
     parser->SetFileName(fileName.c_str());
     parser->Update();
     if (!parser->GetPixelDataFound())
-      {
+    {
       if (!this->ErrorCode)
-        {
+      {
         this->ErrorCode = parser->GetErrorCode();
-        }
-      if (this->ErrorCode || this->RequirePixelData)
-        {
-        continue;
-        }
       }
+      if (this->ErrorCode || this->RequirePixelData)
+      {
+        continue;
+      }
+    }
 
     // Insert the file into the sorted list
     FileInfo fileInfo;
     fileInfo.FileName = fileName;
     fileInfo.StudyUID = meta->GetAttributeValue(DC::StudyInstanceUID);
     fileInfo.SeriesUID = meta->GetAttributeValue(DC::SeriesInstanceUID);
+    fileInfo.InstanceUID = meta->GetAttributeValue(DC::SOPInstanceUID);
     fileInfo.InstanceNumber =
       meta->GetAttributeValue(DC::InstanceNumber).AsUnsignedInt();
 
@@ -304,62 +307,97 @@ void vtkDICOMFileSorter::SortFiles(vtkStringArray *input)
 
     bool foundSeries = false;
     for (li = sortedFiles.begin(); li != sortedFiles.end(); ++li)
-      {
+    {
       // compare studyId first, then seriesId
       int c1 = vtkDICOMUtilities::CompareUIDs(
         studyUID, (*li)[0].StudyUID.GetCharData());
       int c2 = 0;
       if (c1 == 0)
-        {
+      {
         c2 = vtkDICOMUtilities::CompareUIDs(
           seriesUID, (*li)[0].SeriesUID.GetCharData());
-        }
+      }
       if (c1 == 0 && c2 == 0 && seriesUID != 0)
-        {
+      {
         (*li).push_back(fileInfo);
         foundSeries = true;
         break;
-        }
-      else if (c1 >= 0 || (c1 == 0 && c2 >= 0))
-        {
-        break;
-        }
       }
+      else if (c1 >= 0 || (c1 == 0 && c2 >= 0))
+      {
+        break;
+      }
+    }
 
     if (!foundSeries)
-      {
+    {
       std::vector<FileInfo> newSeries;
       newSeries.push_back(fileInfo);
       sortedFiles.insert(li, newSeries);
-      }
     }
+  }
 
   // Sort each series by InstanceNumber
   int studyCount = 0;
 
   vtkDICOMValue lastStudyUID;
   for (li = sortedFiles.begin(); li != sortedFiles.end(); ++li)
-    {
+  {
     std::vector<FileInfo> &v = *li;
     std::stable_sort(v.begin(), v.end(), CompareInstance);
 
     // Is this a new study?
     if (studyCount == 0 || v[0].StudyUID != lastStudyUID)
-      {
+    {
       lastStudyUID = v[0].StudyUID;
       studyCount++;
-      }
-
-    vtkSmartPointer<vtkStringArray> sa =
-      vtkSmartPointer<vtkStringArray>::New();
-    vtkIdType n = static_cast<vtkIdType>(v.size());
-    sa->SetNumberOfValues(n);
-    for (vtkIdType i = 0; i < n; i++)
-      {
-      sa->SetValue(i, v[i].FileName);
-      }
-    this->AddSeriesFileNames(studyCount - 1, sa);
     }
+
+    // Check for duplicate instances, put them into a new series
+    vtkIdType n = static_cast<vtkIdType>(v.size());
+    std::vector<vtkIdType> duplicate(n);
+    std::vector<vtkIdType> seriesLength;
+    seriesLength.push_back(0);
+    vtkIdType numberOfDuplicates = 0;
+    for (vtkIdType i = 0; i < n; i++)
+    {
+      const vtkDICOMValue& uid = v[i].InstanceUID;
+      vtkIdType count = 0;
+      if (uid.GetVL() > 0)
+      {
+        for (vtkIdType j = 0; j < i; j++)
+        {
+          if (v[j].InstanceUID == uid)
+          {
+            count++;
+          }
+        }
+      }
+      duplicate[i] = count;
+      if (count > numberOfDuplicates)
+      {
+        numberOfDuplicates = count;
+        seriesLength.push_back(0);
+      }
+      seriesLength[count]++;
+    }
+
+    for (vtkIdType k = 0; k <= numberOfDuplicates; k++)
+    {
+      vtkSmartPointer<vtkStringArray> sa =
+        vtkSmartPointer<vtkStringArray>::New();
+      sa->SetNumberOfValues(seriesLength[k]);
+      vtkIdType j = 0;
+      for (vtkIdType i = 0; i < n; i++)
+      {
+        if (duplicate[i] == k)
+        {
+          sa->SetValue(j++, v[i].FileName);
+        }
+      }
+      this->AddSeriesFileNames(studyCount - 1, sa);
+    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -369,42 +407,42 @@ void vtkDICOMFileSorter::Execute()
   this->OutputFileNames->Reset();
   this->Series->clear();
   this->Studies->Reset();
-  this->SetInputFileName(0);
+  this->SetInternalFileName(0);
   this->ErrorCode = 0;
 
   if (this->InputFileName) // The input was a single file
-    {
+  {
     int code = vtkDICOMFile::Access(this->InputFileName, vtkDICOMFile::In);
     if (code == vtkDICOMFile::FileNotFound)
-      {
+    {
       this->ErrorCode = vtkErrorCode::FileNotFoundError;
       vtkErrorMacro("File or directory not found: " << this->InputFileName);
       return;
-      }
+    }
     else if (code == vtkDICOMFile::FileIsDirectory)
-      {
+    {
       this->ErrorCode = vtkErrorCode::CannotOpenFileError;
       vtkErrorMacro("Named file is a directory: " << this->InputFileName);
       return;
-      }
+    }
     else if (code == vtkDICOMFile::AccessDenied)
-      {
+    {
       this->ErrorCode = vtkErrorCode::CannotOpenFileError;
       vtkErrorMacro("Permission denied: " << this->InputFileName);
       return;
-      }
+    }
     else if (code == vtkDICOMFile::ImpossiblePath)
-      {
+    {
       this->ErrorCode = vtkErrorCode::CannotOpenFileError;
       vtkErrorMacro("Bad file path: " << this->InputFileName);
       return;
-      }
+    }
     else if (code != 0)
-      {
+    {
       this->ErrorCode = vtkErrorCode::UnknownError;
       vtkErrorMacro("Unknown file error: " << this->InputFileName);
       return;
-      }
+    }
 
     vtkDICOMParser *parser = vtkDICOMParser::New();
     parser->AddObserver(
@@ -417,32 +455,31 @@ void vtkDICOMFileSorter::Execute()
     parser->Delete();
 
     if (!pixelDataFound)
-      {
+    {
       if (!errorCode)
-        {
+      {
         this->ErrorCode = vtkErrorCode::FileFormatError;
         vtkErrorMacro("Not a DICOM image: " << this->InputFileName);
-        }
-      else if (!this->ErrorCode)
-        {
-        this->ErrorCode = errorCode;
-        }
-      return;
       }
+      else if (!this->ErrorCode)
+      {
+        this->ErrorCode = errorCode;
+      }
+      return;
+    }
 
     // Find the path to the file
     vtkDICOMFilePath path(this->InputFileName);
 
     // Create a glob pattern
-    std::string base = path.GetBack(); 
+    std::string base = path.GetBack();
     std::string ext = path.GetExtension();
     std::string pattern = "*";
     if (ext == ".dc" || ext == ".dcm" || ext == ".DC" || ext == ".DCM")
-      {
+    {
       pattern += ext;
-      }
+    }
     path.PopBack();
-    path.PushBack(pattern);
     std::string dirname = path.AsString();
 
     // Find all the files that match the pattern
@@ -452,18 +489,20 @@ void vtkDICOMFileSorter::Execute()
     vtkSmartPointer<vtkStringArray> array =
       vtkSmartPointer<vtkStringArray>::New();
     if (d.GetError() == 0)
-      {
+    {
       int n = d.GetNumberOfFiles();
       for (int i = 0; i < n; i++)
-        {
+      {
         const char *filename = d.GetFile(i);
         if (vtkDICOMUtilities::PatternMatches(pattern.c_str(), filename) &&
             !d.IsDirectory(i))
-          {
-          array->InsertNextValue(filename);
-          }
+        {
+          path.PushBack(filename);
+          array->InsertNextValue(path.AsString());
+          path.PopBack();
         }
       }
+    }
 
     // Sort the files
     this->SortFiles(array);
@@ -472,52 +511,52 @@ void vtkDICOMFileSorter::Execute()
     // twice, once with case-sensitivity and once without
     bool done = false;
     for (int caseless = 0; !done && caseless < 2; caseless++)
-      {
+    {
       if (caseless)
-        {
+      {
         vtkDICOMCharacterSet cs(vtkDICOMCharacterSet::ISO_IR_192);
         base = cs.CaseFoldedUTF8(base.data(), base.length());
-        }
+      }
       for (size_t j = 0; j < this->Series->size() && !done; j++)
-        {
+      {
         vtkStringArray *sa = (*this->Series)[j];
         for (vtkIdType k = 0; k < sa->GetNumberOfValues(); k++)
-          {
+        {
           std::string tmp = vtkDICOMFilePath(sa->GetValue(k)).GetBack();
           if (caseless)
-            {
+          {
             vtkDICOMCharacterSet cs(vtkDICOMCharacterSet::ISO_IR_192);
             tmp = cs.CaseFoldedUTF8(tmp.data(), tmp.length());
-            }
+          }
           if (tmp == base)
-            {
+          {
             this->OutputFileNames->DeepCopy(sa);
             done = true;
             break;
-            }
           }
         }
       }
+    }
 
     // This should never happen
     if (!done)
-      {
-      vtkErrorMacro("Pattern didn't match original file.");
-      }
-    }
-  else if (this->InputFileNames) // The input was a list of files
     {
+      vtkErrorMacro("Pattern didn't match original file.");
+    }
+  }
+  else if (this->InputFileNames) // The input was a list of files
+  {
     this->SortFiles(this->InputFileNames);
 
     for (size_t j = 0; j < this->Series->size(); j++)
-      {
+    {
       vtkStringArray *sa = (*this->Series)[j];
       for (vtkIdType k = 0; k < sa->GetNumberOfValues(); k++)
-        {
+      {
         this->OutputFileNames->InsertNextValue(sa->GetValue(k));
-        }
       }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -526,57 +565,57 @@ void vtkDICOMFileSorter::Update()
   if (this->GetMTime() > this->UpdateTime.GetMTime() ||
       (this->InputFileNames &&
        this->InputFileNames->GetMTime() > this->UpdateTime.GetMTime()))
-    {
+  {
     this->Execute();
     this->UpdateTime.Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMFileSorter::SetInternalFileName(const char *name)
 {
   if (this->InternalFileName == NULL && name == NULL)
-    {
+  {
     return;
-    }
+  }
   if (this->InternalFileName != 0 && name != 0 &&
       strcmp(this->InternalFileName, name) == 0)
-    {
+  {
     return;
-    }
+  }
   if (this->InternalFileName)
-    {
+  {
     delete [] this->InternalFileName;
-    }
+  }
   if (name)
-    {
+  {
     size_t n = strlen(name) + 1;
     char *cp1 =  new char[n];
     const char *cp2 = (name);
     this->InternalFileName = cp1;
     do { *cp1++ = *cp2++; } while (--n);
-    }
+  }
   else
-    {
+  {
     this->InternalFileName = 0;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMFileSorter::RelayError(vtkObject *o, unsigned long e, void *data)
 {
   if (e == vtkCommand::ErrorEvent)
-    {
+  {
     vtkDICOMParser *parser = vtkDICOMParser::SafeDownCast(o);
     if (parser)
-      {
+    {
       this->SetErrorCode(parser->GetErrorCode());
       this->SetInternalFileName(parser->GetFileName());
-      }
+    }
     vtkErrorMacro(<< static_cast<char *>(data));
-    }
+  }
   else
-    {
+  {
     this->InvokeEvent(e, data);
-    }
+  }
 }
