@@ -50,13 +50,13 @@ vtkDICOMMetaData::~vtkDICOMMetaData()
 {
   this->Clear();
   if (this->FileIndexArray)
-    {
+  {
     this->FileIndexArray->Delete();
-    }
+  }
   if (this->FrameIndexArray)
-    {
+  {
     this->FrameIndexArray->Delete();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -65,13 +65,13 @@ void vtkDICOMMetaData::Clear()
   vtkDICOMDataElement **htable = this->Table;
 
   if (htable)
-    {
+  {
     for (unsigned int i = 0; i < METADATA_HASH_SIZE; i++)
-      {
+    {
       delete [] htable[i];
-      }
-    delete [] htable;
     }
+    delete [] htable;
+  }
 
   this->NumberOfDataElements = 0;
   this->Table = NULL;
@@ -85,65 +85,65 @@ void vtkDICOMMetaData::Initialize()
   this->Clear();
   this->NumberOfInstances = 1;
   if (this->FileIndexArray)
-    {
+  {
     this->FileIndexArray->Delete();
     this->FileIndexArray = 0;
-    }
+  }
   if (this->FrameIndexArray)
-    {
+  {
     this->FrameIndexArray->Delete();
     this->FrameIndexArray = 0;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMMetaData::SetNumberOfInstances(int n)
 {
   if (this->Table != NULL)
-    {
+  {
     vtkErrorMacro("SetNumberOfInstances: Cannot set NumberOfInstances after "
                   "attributes have been added");
-    }
+  }
   else
-    {
+  {
     this->NumberOfInstances = n;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMMetaData::SetFileIndexArray(vtkIntArray *a)
 {
   if (this->FileIndexArray != a)
-    {
+  {
     if (this->FileIndexArray)
-      {
+    {
       this->FileIndexArray->Delete();
-      }
+    }
     this->FileIndexArray = a;
     if (this->FileIndexArray)
-      {
+    {
       this->FileIndexArray->Register(this);
-      }
-    this->Modified();
     }
+    this->Modified();
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMMetaData::SetFrameIndexArray(vtkIntArray *a)
 {
   if (this->FrameIndexArray != a)
-    {
+  {
     if (this->FrameIndexArray)
-      {
+    {
       this->FrameIndexArray->Delete();
-      }
+    }
     this->FrameIndexArray = a;
     if (this->FrameIndexArray)
-      {
+    {
       this->FrameIndexArray->Register(this);
-      }
-    this->Modified();
     }
+    this->Modified();
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -156,30 +156,30 @@ void vtkDICOMMetaData::RemoveAttribute(vtkDICOMTag tag)
   vtkDICOMDataElement *hptr;
 
   if (htable && (hptr = htable[i]) != NULL)
-    {
+  {
     while (hptr->Next != 0)
-      {
+    {
       if (hptr->Tag == tag)
-        {
+      {
         // remove from the linked list
         hptr->Next->Prev = hptr->Prev;
         hptr->Prev->Next = hptr->Next;
         // remove from the hash table
         hptr[0] = hptr[1];
         while (hptr->Next != 0)
-          {
+        {
           // adjust links as necessary
           hptr->Prev->Next = hptr;
           hptr->Next->Prev = hptr;
           hptr++;
           hptr[0] = hptr[1];
-          }
+        }
         this->NumberOfDataElements--;
         break;
-        }
-      hptr++;
       }
+      hptr++;
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -193,16 +193,16 @@ vtkDICOMDataElement *vtkDICOMMetaData::FindDataElement(
   vtkDICOMDataElement *hptr;
 
   if (htable && (hptr = htable[i]) != NULL)
-    {
+  {
     while (hptr->Next != 0)
-      {
+    {
       if (hptr->Tag == tag)
-        {
+      {
         return hptr;
-        }
-      hptr++;
       }
+      hptr++;
     }
+  }
 
   return NULL;
 }
@@ -221,23 +221,23 @@ const vtkDICOMValue *vtkDICOMMetaData::FindAttributeValue(
   const vtkDICOMValue *vptr = 0;
 
   if (a != 0)
-    {
+  {
     vptr = &a->Value;
     // is this a sequence of values?
     const vtkDICOMValue *sptr = vptr->GetMultiplexData();
     if (sptr)
-      {
+    {
       size_t n = vptr->GetNumberOfValues();
       vptr = 0;
       if (idx >= 0 && static_cast<size_t>(idx) < n)
-        {
+      {
         if (sptr[idx].IsValid())
-          {
+        {
           vptr = &sptr[idx];
-          }
         }
       }
     }
+  }
 
   return vptr;
 }
@@ -248,20 +248,20 @@ const vtkDICOMValue *vtkDICOMMetaData::FindAttributeValue(
 {
   const vtkDICOMValue *vptr = this->FindAttributeValue(idx, tagpath.GetHead());
   if (vptr != 0 && tagpath.HasTail())
-    {
-    unsigned int i = tagpath.GetIndex();
-    unsigned int n = vptr->GetNumberOfValues();
+  {
+    size_t i = tagpath.GetIndex();
+    size_t n = vptr->GetNumberOfValues();
     const vtkDICOMItem *items = vptr->GetSequenceData();
     vptr = 0;
     if (items != 0 && i < n)
-      {
+    {
       vptr = &items[i].GetAttributeValue(tagpath.GetTail());
       if (!vptr->IsValid())
-        {
+      {
         vptr = 0;
-        }
       }
     }
+  }
   return vptr;
 }
 
@@ -314,51 +314,51 @@ const vtkDICOMValue &vtkDICOMMetaData::GetAttributeValue(
   // (if frame is "-1", then only search SharedFunctionalGroups)
   int istart = (frame < 0 ? 1 : 0);
   for (int i = istart; i < 2; i++)
-    {
+  {
     // we only need the frame number for the PerFrame sequence
     size_t f = (i == 0 ? frame : 0);
     const vtkDICOMValue *seq = this->FindAttributeValue(idx, fgs[i]);
     if (seq && f < seq->GetNumberOfValues())
-      {
+    {
       // search for the item that matches the frame
       const vtkDICOMItem *items = seq->GetSequenceData();
       const vtkDICOMValue &v = items[f].GetAttributeValue(tagpath);
       if (v.IsValid())
-        {
+      {
         return v;
-        }
+      }
       // search within all the sequences in the item
       vtkDICOMDataElementIterator iter = items[f].Begin();
       vtkDICOMDataElementIterator iterEnd = items[f].End();
       while (iter != iterEnd)
-        {
+      {
         const vtkDICOMValue &u = iter->GetValue();
         if (u.GetNumberOfValues() == 1)
-          {
+        {
           const vtkDICOMItem *item = u.GetSequenceData();
           if (item)
-            {
+          {
             const vtkDICOMValue &w = item->GetAttributeValue(tagpath);
             if (w.IsValid())
-              {
+            {
               if ((iter->GetTag().GetGroup() & 1) == 0)
-                {
+              {
                 return w;
-                }
+              }
               else if (privateValue == 0)
-                {
+              {
                 // if we found the attribute in a private sequence,
                 // then save but and keep searching to see if it will
                 // eventually be found somewhere public
                 privateValue = &w;
-                }
               }
             }
           }
-        ++iter;
         }
+        ++iter;
       }
     }
+  }
 
   // search root last of all
   const vtkDICOMValue *vptr = this->FindAttributeValue(idx, tagpath);
@@ -381,9 +381,9 @@ int vtkDICOMMetaData::GetFileIndex(int sliceIdx)
 {
   if (this->FileIndexArray == 0 || sliceIdx < 0 ||
       sliceIdx >= this->FileIndexArray->GetNumberOfTuples())
-    {
+  {
     return -1;
-    }
+  }
 
   int n = this->FileIndexArray->GetNumberOfComponents();
   return this->FileIndexArray->GetValue(sliceIdx*n);
@@ -395,9 +395,9 @@ int vtkDICOMMetaData::GetFileIndex(int sliceIdx, int compIdx, int numComp)
   if (this->FileIndexArray == 0 || sliceIdx < 0 ||
       sliceIdx >= this->FileIndexArray->GetNumberOfTuples() ||
       compIdx < 0 || compIdx >= numComp)
-    {
+  {
     return -1;
-    }
+  }
 
   int n = this->FileIndexArray->GetNumberOfComponents();
   return this->FileIndexArray->GetValue(sliceIdx*n + compIdx*n/numComp);
@@ -408,9 +408,9 @@ int vtkDICOMMetaData::GetFrameIndex(int sliceIdx)
 {
   if (this->FrameIndexArray == 0 || sliceIdx < 0 ||
       sliceIdx >= this->FrameIndexArray->GetNumberOfTuples())
-    {
+  {
     return -1;
-    }
+  }
 
   int n = this->FrameIndexArray->GetNumberOfComponents();
   return this->FrameIndexArray->GetValue(sliceIdx*n);
@@ -422,9 +422,9 @@ int vtkDICOMMetaData::GetFrameIndex(int sliceIdx, int compIdx, int numComp)
   if (this->FrameIndexArray == 0 || sliceIdx < 0 ||
       sliceIdx >= this->FrameIndexArray->GetNumberOfTuples() ||
       compIdx < 0 || compIdx >= numComp)
-    {
+  {
     return -1;
-    }
+  }
 
   int n = this->FrameIndexArray->GetNumberOfComponents();
   return this->FrameIndexArray->GetValue(sliceIdx*n + compIdx*n/numComp);
@@ -442,62 +442,62 @@ vtkDICOMDataElement *vtkDICOMMetaData::FindDataElementOrInsert(
   vtkDICOMDataElement *hptr;
 
   if (htable == NULL)
-    {
+  {
     // allocate the hash table
     m = METADATA_HASH_SIZE;
     htable = new vtkDICOMDataElement *[METADATA_HASH_SIZE];
     this->Table = htable;
     do { *htable++ = NULL; } while (--m);
     htable = this->Table;
-    }
+  }
 
   hptr = htable[i];
 
   if (hptr == NULL)
-    {
+  {
     hptr = new vtkDICOMDataElement[4];
     htable[i] = hptr;
-    }
+  }
   else if (hptr->Next != 0)
-    {
+  {
     // see if item is already there
     unsigned int n = 0;
     do
-      {
+    {
       if (hptr->Tag == tag)
-        {
+      {
         return hptr;
-        }
+      }
       n++;
       hptr++;
-      }
+    }
     while (hptr->Next != 0);
 
     // if n+1 is a power of two, double allocated space
     if (n > 2 && (n & (n+1)) == 0)
-      {
+    {
       vtkDICOMDataElement *oldptr = htable[i];
       hptr = new vtkDICOMDataElement[2*(n+1)];
       htable[i] = hptr;
       // copy the old list
       for (unsigned int j = 0; j < n; j++)
-        {
+      {
         *hptr = oldptr[j];
         // link the new element into the list
         hptr->Next->Prev = hptr;
         hptr->Prev->Next = hptr;
         hptr++;
-        }
-      delete [] oldptr;
       }
+      delete [] oldptr;
     }
+  }
 
   // insert into the linked list
   vtkDICOMDataElement *tptr = &this->Tail;
   do
-    {
+  {
     tptr = tptr->Prev;
-    }
+  }
   while (tag < tptr->GetTag());
 
   hptr->Prev = tptr;
@@ -518,109 +518,109 @@ int vtkDICOMMetaData::FindItemsOrInsert(
 
   vtkDICOMDataElement *loc = this->FindDataElementOrInsert(tag);
   if (loc == 0)
-    {
+  {
     vtkErrorMacro("SetAttributeValue: tag group number must not be zero.");
     return 0;
-    }
+  }
 
   loc->Tag = tag;
   vtkDICOMValue *vptr = &loc->Value;
   if (!vptr->IsValid())
-    {
+  {
     vtkDICOMVR vr = this->FindDictVR(idx, tag);
     if (vr != vtkDICOMVR::SQ && vr != vtkDICOMVR::UN)
-      {
+    {
       // we just inserted a non-SQ value, remove it
       this->RemoveAttribute(tag);
       return 0;
-      }
     }
+  }
   else if (vptr->GetVR() != vtkDICOMVR::SQ)
-    {
+  {
     return 0;
-    }
+  }
 
   // is this a series of values?
   int count = 1;
   vtkDICOMValue *sptr = vtkDICOMValueFriendMetaData::GetMultiplex(vptr);
   if (sptr != 0)
-    {
+  {
     if (useidx)
-      {
+    {
       assert(idx >= 0 && idx < this->NumberOfInstances);
       sptr = &sptr[idx];
-      }
-    else
-      {
-      count = this->NumberOfInstances;
-      }
     }
-  else if (useidx && this->NumberOfInstances > 1)
+    else
     {
+      count = this->NumberOfInstances;
+    }
+  }
+  else if (useidx && this->NumberOfInstances > 1)
+  {
     // create a multiplex
     assert(idx >= 0 && idx < this->NumberOfInstances);
     int n = this->NumberOfInstances;
     vtkDICOMValue l;
     sptr = l.AllocateMultiplexData(vtkDICOMVR::SQ, n);
     for (int i = 0; i < n; i++)
-      {
+    {
       if (i != idx)
-        {
+      {
         sptr[i] = *vptr;
-        }
       }
+    }
     *vptr = l;
     sptr = &sptr[idx];
-    }
+  }
   else
-    {
+  {
     sptr = vptr;
-    }
+  }
 
-  unsigned int i = tagpath.GetIndex();
+  size_t i = tagpath.GetIndex();
   for (int k = 0; k < count; k++)
-    {
-    unsigned int n = i+1;
-    unsigned int m = 0;
+  {
+    size_t n = i+1;
+    size_t m = 0;
     const vtkDICOMItem *oldItems = sptr[k].GetSequenceData();
     if (oldItems != 0)
-      {
+    {
       m = sptr[k].GetNumberOfValues();
       n = (n > m ? n : m);
-      }
+    }
     vtkDICOMValue seq;
     vtkDICOMItem *items = seq.AllocateSequenceData(vtkDICOMVR::SQ, n);
     // copy the old sequence into the new one (shallow copy)
-    for (unsigned int j = 0; j < m; j++)
-      {
+    for (size_t j = 0; j < m; j++)
+    {
       items[j] = oldItems[j];
-      }
+    }
     // Get the character set and default VR for XS
     vtkDICOMCharacterSet cs = vtkDICOMCharacterSet::ISO_IR_6;
     vtkDICOMVR vrForXS = vtkDICOMVR::US;
     if (n > m)
-      {
+    {
       const vtkDICOMValue& vcs =
         this->GetAttributeValue(DC::SpecificCharacterSet);
       if (vcs.IsValid())
-        {
+      {
         cs = vtkDICOMCharacterSet(vcs.GetCharData(), vcs.GetVL());
-        }
+      }
       const vtkDICOMValue &v = this->GetAttributeValue(
         DC::PixelRepresentation);
       if (v.IsValid())
-        {
+      {
         vrForXS = (v.AsUnsignedShort() == 0 ?
                    vtkDICOMVR::US : vtkDICOMVR::SS);
-        }
       }
-    for (unsigned int j = m; j < n; j++)
-      {
+    }
+    for (size_t j = m; j < n; j++)
+    {
       items[j] = vtkDICOMItem(cs, vrForXS);
-      }
+    }
     sptr[k] = seq;
     itemarray[k] = &items[i];
-    }
+  }
 
   return count;
 }
@@ -639,53 +639,53 @@ void vtkDICOMMetaData::SetAttributeValue(
   vtkDICOMTag tag, const vtkDICOMValue& v)
 {
   if (v.IsValid())
-    {
+  {
     vtkDICOMDataElement *loc = this->FindDataElementOrInsert(tag);
     if (loc == 0)
-      {
+    {
       vtkErrorMacro("SetAttributeValue: tag group number must not be zero.");
       return;
-      }
+    }
     loc->Tag = tag;
     loc->Value = v;
-    }
+  }
   else
-    {
+  {
     this->RemoveAttribute(tag);
-    }
+  }
 }
 
 void vtkDICOMMetaData::SetAttributeValue(vtkDICOMTag tag, double v)
 {
   vtkDICOMVR vr = this->FindDictVR(0, tag);
   if (vr != vtkDICOMVR::UN)
-    {
+  {
     this->SetAttributeValue(tag, vtkDICOMValue(vr, v));
-    }
+  }
   else
-    {
+  {
     vtkErrorMacro("SetAttributeValue: could not find tag (" <<
                   tag << ") in the dictionary");
-    }
+  }
 }
 
 void vtkDICOMMetaData::SetAttributeValue(vtkDICOMTag tag, const std::string& v)
 {
   vtkDICOMVR vr = this->FindDictVR(0, tag);
   if (vr.HasSpecificCharacterSet() && tag > DC::SpecificCharacterSet)
-    {
+  {
     this->SetAttributeValue(tag,
       this->MakeValueWithSpecificCharacterSet(vr, v));
-    }
+  }
   else if (vr != vtkDICOMVR::UN)
-    {
+  {
     this->SetAttributeValue(tag, vtkDICOMValue(vr, v));
-    }
+  }
   else
-    {
+  {
     vtkErrorMacro("SetAttributeValue: could not find tag (" <<
                   tag << ") in the dictionary");
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -695,10 +695,10 @@ void vtkDICOMMetaData::SetAttributeValue(
 {
   vtkDICOMDataElement *loc = this->FindDataElementOrInsert(tag);
   if (loc == 0)
-    {
+  {
     vtkErrorMacro("SetAttributeValue: tag group number must not be zero.");
     return;
-    }
+  }
 
   loc->Tag = tag;
   vtkDICOMValue *vptr = &loc->Value;
@@ -708,46 +708,46 @@ void vtkDICOMMetaData::SetAttributeValue(
   // is this a sequence of values?
   vtkDICOMValue *sptr = vtkDICOMValueFriendMetaData::GetMultiplex(vptr);
   if (sptr)
-    {
+  {
     sptr[idx] = v;
     // if invalid value was added, make sure valid values remain
     if (!v.IsValid())
-      {
+    {
       bool valid = false;
       for (int i = 0; i < this->NumberOfInstances; i++)
-        {
+      {
         valid |= sptr[i].IsValid();
-        }
+      }
       if (!valid)
-        {
+      {
         this->RemoveAttribute(tag);
-        }
       }
     }
+  }
   else if (v != *vptr)
-    {
+  {
     // differs from other instances, must turn value into a list,
     // so create a value that is actually a list of values
     int n = this->NumberOfInstances;
     vtkDICOMValue l;
     sptr = l.AllocateMultiplexData(vptr->GetVR(), n);
     for (int i = 0; i < n; i++)
-      {
-      if (i == idx)
-        {
-        sptr[i] = v;
-        }
-      else
-        {
-        sptr[i] = *vptr;
-        }
-      }
-    *vptr = l;
-    }
-  else if (!vptr->IsValid())
     {
-    this->RemoveAttribute(tag);
+      if (i == idx)
+      {
+        sptr[i] = v;
+      }
+      else
+      {
+        sptr[i] = *vptr;
+      }
     }
+    *vptr = l;
+  }
+  else if (!vptr->IsValid())
+  {
+    this->RemoveAttribute(tag);
+  }
 }
 
 void vtkDICOMMetaData::SetAttributeValue(
@@ -755,14 +755,14 @@ void vtkDICOMMetaData::SetAttributeValue(
 {
   vtkDICOMVR vr = this->FindDictVR(idx, tag);
   if (vr != vtkDICOMVR::UN)
-    {
+  {
     this->SetAttributeValue(idx, tag, vtkDICOMValue(vr, v));
-    }
+  }
   else
-    {
+  {
     vtkErrorMacro("SetAttributeValue: could not find tag (" <<
                   tag << ") in the dictionary");
-    }
+  }
 }
 
 void vtkDICOMMetaData::SetAttributeValue(
@@ -770,19 +770,19 @@ void vtkDICOMMetaData::SetAttributeValue(
 {
   vtkDICOMVR vr = this->FindDictVR(idx, tag);
   if (vr.HasSpecificCharacterSet() && tag > DC::SpecificCharacterSet)
-    {
+  {
     this->SetAttributeValue(idx, tag,
       this->MakeValueWithSpecificCharacterSet(vr, v));
-    }
+  }
   else if (vr != vtkDICOMVR::UN)
-    {
+  {
     this->SetAttributeValue(idx, tag, vtkDICOMValue(vr, v));
-    }
+  }
   else
-    {
+  {
     vtkErrorMacro("SetAttributeValue: could not find tag (" <<
                   tag << ") in the dictionary");
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -791,57 +791,57 @@ void vtkDICOMMetaData::SetAttributeValue(
   const vtkDICOMTagPath& tagpath, const vtkDICOMValue& v)
 {
   if (tagpath.HasTail())
-    {
+  {
     vtkDICOMItem **items = new vtkDICOMItem *[this->NumberOfInstances];
     int n = this->FindItemsOrInsert(0, false, tagpath, items);
     for (int i = 0; i < n; i++)
-      {
-      items[i]->SetAttributeValue(tagpath.GetTail(), v);
-      }
-    delete [] items;
-    }
-  else
     {
-    this->SetAttributeValue(tagpath.GetHead(), v);
+      items[i]->SetAttributeValue(tagpath.GetTail(), v);
     }
+    delete [] items;
+  }
+  else
+  {
+    this->SetAttributeValue(tagpath.GetHead(), v);
+  }
 }
 
 void vtkDICOMMetaData::SetAttributeValue(
   const vtkDICOMTagPath& tagpath, double v)
 {
   if (tagpath.HasTail())
-    {
+  {
     vtkDICOMItem **items = new vtkDICOMItem *[this->NumberOfInstances];
     int n = this->FindItemsOrInsert(0, false, tagpath, items);
     for (int i = 0; i < n; i++)
-      {
-      items[i]->SetAttributeValue(tagpath.GetTail(), v);
-      }
-    delete [] items;
-    }
-  else
     {
-    this->SetAttributeValue(tagpath.GetHead(), v);
+      items[i]->SetAttributeValue(tagpath.GetTail(), v);
     }
+    delete [] items;
+  }
+  else
+  {
+    this->SetAttributeValue(tagpath.GetHead(), v);
+  }
 }
 
 void vtkDICOMMetaData::SetAttributeValue(
   const vtkDICOMTagPath& tagpath, const std::string& v)
 {
   if (tagpath.HasTail())
-    {
+  {
     vtkDICOMItem **items = new vtkDICOMItem *[this->NumberOfInstances];
     int n = this->FindItemsOrInsert(0, false, tagpath, items);
     for (int i = 0; i < n; i++)
-      {
-      items[i]->SetAttributeValue(tagpath.GetTail(), v);
-      }
-    delete [] items;
-    }
-  else
     {
-    this->SetAttributeValue(tagpath.GetHead(), v);
+      items[i]->SetAttributeValue(tagpath.GetTail(), v);
     }
+    delete [] items;
+  }
+  else
+  {
+    this->SetAttributeValue(tagpath.GetHead(), v);
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -850,51 +850,51 @@ void vtkDICOMMetaData::SetAttributeValue(
   int idx, const vtkDICOMTagPath& tagpath, const vtkDICOMValue& v)
 {
   if (tagpath.HasTail())
-    {
+  {
     vtkDICOMItem *item = this->FindItemOrInsert(idx, tagpath);
     if (item)
-      {
-      item->SetAttributeValue(tagpath.GetTail(), v);
-      }
-    }
-  else
     {
-    this->SetAttributeValue(idx, tagpath.GetHead(), v);
+      item->SetAttributeValue(tagpath.GetTail(), v);
     }
+  }
+  else
+  {
+    this->SetAttributeValue(idx, tagpath.GetHead(), v);
+  }
 }
 
 void vtkDICOMMetaData::SetAttributeValue(
   int idx, const vtkDICOMTagPath& tagpath, double v)
 {
   if (tagpath.HasTail())
-    {
+  {
     vtkDICOMItem *item = this->FindItemOrInsert(idx, tagpath);
     if (item)
-      {
-      item->SetAttributeValue(tagpath.GetTail(), v);
-      }
-    }
-  else
     {
-    this->SetAttributeValue(idx, tagpath.GetHead(), v);
+      item->SetAttributeValue(tagpath.GetTail(), v);
     }
+  }
+  else
+  {
+    this->SetAttributeValue(idx, tagpath.GetHead(), v);
+  }
 }
 
 void vtkDICOMMetaData::SetAttributeValue(
   int idx, const vtkDICOMTagPath& tagpath, const std::string& v)
 {
   if (tagpath.HasTail())
-    {
+  {
     vtkDICOMItem *item = this->FindItemOrInsert(idx, tagpath);
     if (item)
-      {
-      item->SetAttributeValue(tagpath.GetTail(), v);
-      }
-    }
-  else
     {
-    this->SetAttributeValue(idx, tagpath.GetHead(), v);
+      item->SetAttributeValue(tagpath.GetTail(), v);
     }
+  }
+  else
+  {
+    this->SetAttributeValue(idx, tagpath.GetHead(), v);
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -906,9 +906,9 @@ vtkDICOMValue vtkDICOMMetaData::MakeValueWithSpecificCharacterSet(
   const vtkDICOMValue& vcs =
     this->GetAttributeValue(DC::SpecificCharacterSet);
   if (vcs.IsValid())
-    {
+  {
     cs = vtkDICOMCharacterSet(vcs.GetCharData(), vcs.GetVL());
-    }
+  }
   return vtkDICOMValue(vr, cs, v);
 }
 
@@ -920,37 +920,37 @@ void vtkDICOMMetaData::CopyAttributes(vtkDICOMMetaData *o)
   // can safely have private tags when this method is called.
 
   if (o != 0 && o != this)
-    {
+  {
     vtkDICOMDataElement **otable = o->Table;
     if (otable != 0)
-      {
+    {
       const vtkDICOMDataElement *iter = o->Head.Next;
       const vtkDICOMDataElement *iterEnd = &o->Tail;
       while (iter != iterEnd)
-        {
+      {
         // if this is a per-instance element, then make a copy of it
         const vtkDICOMValue *vptr = iter->Value.GetMultiplexData();
         if (vptr == 0)
-          {
+        {
           vtkDICOMDataElement *e = this->FindDataElementOrInsert(iter->Tag);
           e->Tag = iter->Tag;
           e->Value = iter->Value;
-          }
+        }
         else if (this->NumberOfInstances == o->NumberOfInstances)
-          {
+        {
           vtkDICOMDataElement *e = this->FindDataElementOrInsert(iter->Tag);
           e->Tag = iter->Tag;
           vtkDICOMValue *nvptr = e->Value.AllocateMultiplexData(
             iter->Value.GetVR(), this->NumberOfInstances);
           for (int i = 0; i < this->NumberOfInstances; i++)
-            {
+          {
             nvptr[i] = vptr[i];
-            }
           }
-        iter = iter->Next;
         }
+        iter = iter->Next;
       }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -958,17 +958,17 @@ void vtkDICOMMetaData::ShallowCopy(vtkDataObject *source)
 {
   vtkDICOMMetaData *o = vtkDICOMMetaData::SafeDownCast(source);
   if (o != this)
-    {
+  {
     this->Initialize();
     if (o != 0)
-      {
+    {
       this->NumberOfInstances = o->NumberOfInstances;
       this->CopyAttributes(o);
       this->SetFileIndexArray(o->FileIndexArray);
       this->SetFrameIndexArray(o->FrameIndexArray);
-      }
-    this->vtkDataObject::ShallowCopy(source);
     }
+    this->vtkDataObject::ShallowCopy(source);
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -976,25 +976,25 @@ void vtkDICOMMetaData::DeepCopy(vtkDataObject *source)
 {
   vtkDICOMMetaData *o = vtkDICOMMetaData::SafeDownCast(source);
   if (o != this)
-    {
+  {
     this->Initialize();
     if (o != 0)
-      {
+    {
       this->NumberOfInstances = o->NumberOfInstances;
       this->CopyAttributes(o);
       if (o->FileIndexArray)
-        {
+      {
         this->FileIndexArray = vtkIntArray::New();
         this->FileIndexArray->DeepCopy(o->FileIndexArray);
-        }
+      }
       if (o->FrameIndexArray)
-        {
+      {
         this->FrameIndexArray = vtkIntArray::New();
         this->FrameIndexArray->DeepCopy(o->FrameIndexArray);
-        }
       }
-    this->vtkDataObject::DeepCopy(source);
     }
+    this->vtkDataObject::DeepCopy(source);
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1005,60 +1005,60 @@ vtkDICOMVR vtkDICOMMetaData::FindDictVR(int idx, vtkDICOMTag tag)
   vtkDICOMDictEntry e = this->FindDictEntry(tag);
 
   if (e.IsValid())
-    {
+  {
     vr = e.GetVR();
     // use the dictionary VR
     if (vr == vtkDICOMVR::XS)
-      {
+    {
       vr = vtkDICOMVR::US;
       const vtkDICOMValue &v =
         this->GetAttributeValue(idx, DC::PixelRepresentation);
       if (v.IsValid())
-        {
+      {
         unsigned short r = v.AsUnsignedShort();
         vr = (r == 0 ? vtkDICOMVR::US : vtkDICOMVR::SS);
-        }
+      }
       else if (tag > DC::PixelRepresentation)
-        {
+      {
         vtkErrorMacro("SetAttributeValue: could not look up vr for (" <<
                       tag << ") because PixelRepresentation is not set.");
-        }
       }
+    }
     else if (vr == vtkDICOMVR::OX)
-      {
+    {
       vr = vtkDICOMVR::OW;
       if (tag.GetGroup() == 0x5400)
-        {
+      {
         const vtkDICOMValue &v =
           this->GetAttributeValue(idx, DC::WaveformBitsAllocated);
         if (v.IsValid())
-          {
+        {
           unsigned short s = v.AsUnsignedShort();
           vr = (s > 8 ? vtkDICOMVR::OW : vtkDICOMVR::OB);
-          }
+        }
         else
-          {
+        {
           vtkErrorMacro("SetAttributeValue: could not look up vr for (" <<
                         tag << ") because WaveformBitsAllocated is not set.");
-          }
         }
+      }
       else
-        {
+      {
         const vtkDICOMValue &v =
           this->GetAttributeValue(idx, DC::BitsAllocated);
         if (v.IsValid())
-          {
+        {
           unsigned short s = v.AsUnsignedShort();
           vr = (s > 8 ? vtkDICOMVR::OW : vtkDICOMVR::OB);
-          }
+        }
         else
-          {
+        {
           vtkErrorMacro("SetAttributeValue: could not look up vr for (" <<
                         tag << ") because BitsAllocated is not set.");
-          }
         }
       }
     }
+  }
 
   return vr;
 }
@@ -1069,9 +1069,9 @@ vtkDICOMTag vtkDICOMMetaData::ResolvePrivateTag(
 {
   unsigned short g = ptag.GetGroup();
   if ((g & 0x0001) == 0)
-    {
+  {
     return ptag;
-    }
+  }
 
   // if not resolved, the result will be (ffff,ffff)
   vtkDICOMTag otag(0xFFFF, 0xFFFF);
@@ -1083,31 +1083,31 @@ vtkDICOMTag vtkDICOMMetaData::ResolvePrivateTag(
 
   vtkDICOMDataElement *e = this->FindDataElement(ctag);
   if (e != 0)
-    {
+  {
     // found (gggg,0010) in the hash table
     iter = vtkDICOMDataElementIterator(e);
-    }
+  }
   else
-    {
+  {
     // skip through list of elements until group is found
     while (iter != iterEnd && iter->GetTag() < ctag)
-      {
+    {
       ++iter;
-      }
     }
+  }
 
   // look for private creator elements within the group
   while (iter != iterEnd && iter->GetTag() <= etag)
-    {
+  {
     ctag = iter->GetTag();
     if (iter->GetValue().AsString() == creator)
-      {
+    {
       otag = vtkDICOMTag(
         g, (ctag.GetElement() << 8) | (ptag.GetElement() & 0x00FF));
       break;
-      }
-    ++iter;
     }
+    ++iter;
+  }
 
   return otag;
 }
@@ -1118,23 +1118,23 @@ vtkDICOMTag vtkDICOMMetaData::ResolvePrivateTagForWriting(
 {
   vtkDICOMTag otag = this->ResolvePrivateTag(ptag, creator);
   if (otag == vtkDICOMTag(0xFFFF, 0xFFFF))
-    {
+  {
     unsigned short g = ptag.GetGroup();
     for (unsigned short e = 0x0010; e <= 0x00FF; e++)
-      {
+    {
       vtkDICOMTag ctag(g, e);
       vtkDICOMDataElement *d = this->FindDataElementOrInsert(ctag);
       if (!d->Value.IsValid())
-        {
+      {
         // if an empty slot was found, use it for this creator
         d->Tag = ctag;
         d->Value = this->MakeValueWithSpecificCharacterSet(
           vtkDICOMVR::LO, creator);
         otag = vtkDICOMTag(g, (e << 8) | (ptag.GetElement() & 0x00FF));
         break;
-        }
       }
     }
+  }
 
   return otag;
 }
@@ -1148,13 +1148,13 @@ vtkDICOMDictEntry vtkDICOMMetaData::FindDictEntry(vtkDICOMTag tag)
   // note that there is similar code in vtkDICOMItem
   const char *dict = 0;
   if ((group & 1) != 0 && element > 0x00ffu)
-    {
+  {
     unsigned short creatorElement = (element >> 8);
     element &= 0x00ffu;
     tag = vtkDICOMTag(group, element);
     vtkDICOMTag creatorTag(group, creatorElement);
     dict = this->GetAttributeValue(creatorTag).GetCharData();
-    }
+  }
 
   return vtkDICOMDictionary::FindDictEntry(tag, dict);
 }
