@@ -16,6 +16,7 @@
 #include <vtkStringArray.h>
 #include <vtkObjectFactory.h>
 #include "vtkDICOMUtilities.h"
+#include "vtkDICOMUIDGenerator.h"
 #include "vtkDICOMFile.h"
 #include "vtkDICOMConfig.h"
 
@@ -39,403 +40,18 @@
 
 vtkStandardNewMacro(vtkDICOMUtilities);
 
-namespace {
-
-// divide a hex string by 10, return remainder
-int vtkDivideHexStringBy10(char *value)
-{
-  char *cp = value;
-
-  // convert hex string to binary
-  unsigned int x = 0;
-  while (*cp != '\0')
-    {
-    // skip any hyphens
-    if (*cp == '-')
-      {
-      cp++;
-      continue;
-      }
-
-    // convert hex digit to a nibble
-    unsigned int d = *cp;
-    if ((d -= '0') > 9)
-      {
-      if ((d -= ('A' - '0' - 10)) > 15)
-        {
-        d -= ('a' - 'A');
-        }
-      }
-
-    // append the nibble
-    x <<= 4;
-    x += d;
-
-    // divide by 10
-    unsigned int y = (10 << 3);
-    unsigned int z = 0;
-    int i;
-    for (i = 0; i < 4; i++)
-      {
-      z <<= 1;
-      int nx = x - y;
-      if (nx >= 0)
-        {
-        x = nx;
-        z++;
-        }
-      y >>= 1;
-      }
-
-    // convert quotient to new hex digit
-    if ((z += '0') > '9')
-      {
-      z += ('A' - '0' - 10);
-      }
-
-    *cp++ = static_cast<char>(z);
-    }
-
-  // return the remainder
-  return static_cast<int>(x);
-}
-
-// convert a hex uuid string to a decimal uid string, the
-// supplied uid will be at most 1.5 times as long as the uuid
-void vtkConvertHexToDecimal(const char *uuid, char *uid)
-{
-  // max characters in a uuid and uid
-  const unsigned int uuidlen = 36;
-  const unsigned int uidlen = 64;
-
-  char x[uuidlen + 4];
-  char y[uidlen + 4];
-
-  if (uuid[0] == '0' && uuid[1] == 'x')
-    {
-    uuid += 2;
-    }
-
-  strncpy(x, uuid, uuidlen);
-  x[uuidlen] = '\0';
-
-  char *cp = y + uidlen;
-  *cp = '\0';
-
-  char *dp = x;
-  do
-    {
-    *(--cp) = vtkDivideHexStringBy10(x) + '0';
-    // remove any leading zeros
-    while (*dp == '0' || *dp == '-')
-      {
-      dp++;
-      }
-    }
-  while (*dp != '\0');
-
-  // copy out the result
-  strcpy(uid, cp);
-}
-
-// convert a byte into two hexadecimal digits
-inline void vtkGenerateHexDigits(unsigned char y, char cp[2])
-{
-  unsigned int z = (y >> 4);
-  for (int j = 0; j < 2; j++)
-    {
-    if ((z += '0') > '9')
-      {
-      z += ('A' - '0' - 10);
-      }
-    cp[j] = static_cast<char>(z);
-    z = (y & 0x0F);
-    }
-}
-
-// convert n bytes into 2*n hexadecimal digits
-void vtkConvertBytesToHex(const unsigned char *bytes, size_t n, char *cp)
-{
-  for (size_t i = 0; i < n; i++)
-    {
-    vtkGenerateHexDigits(*bytes, cp);
-    bytes++;
-    cp += 2;
-    }
-  *cp = '\0';
-}
-
-// generate a 36-character uuid from a 128-bit random number
-// (the supplied pointer must have 37 bytes of available space)
-void vtkConvertRandomToUUID(const unsigned char bytes[16], char *uuid)
-{
-  // copy it so that we can modify it
-  char r[16];
-  for (int j = 0; j < 16; j++)
-    {
-    r[j] = bytes[j];
-    }
-
-  // set bits to show that this is a version 4 uuid
-  r[6] = ((r[6] & 0x0f) | 0x40);
-
-  // set the uuid variant to "0b10" (0b == binary)
-  r[8] = ((r[8] & 0x3f) | 0x80);
-
-  // convert the uuid into hexidecimal text
-  char *cp = uuid;
-  for (unsigned int i = 0; i < 16; i++)
-    {
-    // add hyphens to the uuid (just to be pedantic)
-    if (i == 4 || i == 6 || i == 8 || i == 10)
-      {
-      *cp++ = '-';
-      }
-
-    vtkGenerateHexDigits(r[i], cp);
-    cp += 2;
-    }
-
-  *cp = '\0';
-}
-
-// convert a 36-character uuid to a 44-character uid
-void vtkConvertUUIDToUID(const char *uuid, char *uid)
-{
-  strncpy(uid, "2.25.", 5);
-  vtkConvertHexToDecimal(uuid, uid + 5);
-}
-
-// read from the random number generator
-void vtkGenerateRandomBytes(unsigned char *bytes, vtkIdType n)
-{
-  int r = 0;
-#ifdef _WIN32
-  // use the Windows cryptography interface (WinXP and later)
-  HCRYPTPROV hProv;
-  r = CryptAcquireContext(&hProv, NULL, NULL, PROV_RSA_FULL,
-                          CRYPT_SILENT);
-  if (r == 0 && GetLastError() == NTE_BAD_KEYSET)
-    {
-    r = CryptAcquireContext(&hProv, NULL, NULL, PROV_RSA_FULL,
-                            CRYPT_SILENT | CRYPT_NEWKEYSET);
-    }
-  if (r != 0)
-    {
-    r = CryptGenRandom(hProv, n, reinterpret_cast<BYTE *>(bytes));
-    CryptReleaseContext(hProv, 0);
-    }
-#else
-  vtkDICOMFile infile("/dev/urandom", vtkDICOMFile::In);
-  if (infile.GetError() == 0)
-    {
-    size_t m = infile.Read(bytes, n);
-    r = (m == static_cast<size_t>(n));
-    infile.Close();
-    }
-#endif
-  if (r == 0)
-    {
-    memset(bytes, '\0', n);
-    vtkGenericWarningMacro(
-      "vtkDICOMUtilities::GenerateUID() failed to read from "
-      "the random number generator");
-    }
-}
-
-// to add a little bit of recognizability to UIDs
-char vtkDICOMTagToDigit(vtkDICOMTag tag)
-{
-  char d = '1';
-
-  if (tag == DC::SOPInstanceUID ||
-      tag == DC::MediaStorageSOPInstanceUID)
-    {
-    d = '2';
-    }
-  else if (tag == DC::SeriesInstanceUID ||
-           tag == DC::ConcatenationUID)
-    {
-    d = '3';
-    }
-  else if (tag == DC::StudyInstanceUID)
-    {
-    d = '4';
-    }
-  else if (tag == DC::FrameOfReferenceUID ||
-           tag == DC::VolumeFrameOfReferenceUID ||
-           tag == DC::SourceFrameOfReferenceUID ||
-           tag == DC::SynchronizationFrameOfReferenceUID ||
-           tag == DC::TableFrameOfReferenceUID)
-    {
-    d = '5';
-    }
-
-  return d;
-}
-
-// get the number of random bytes to generate after this prefix
-vtkIdType vtkRandomBytesForPrefix(const char *prefix)
-{
-  size_t n = strlen(prefix);
-  if (n > 0 && prefix[n-1] != '.')
-    {
-    n++;
-    }
-  n = 64 - n;
-  vtkIdType m = 0;
-  if (n > 40)
-    {
-    m = 16; // use 128 bit random number
-    }
-  else
-    {
-    m = 12; // use 96 bit random number
-    }
-
-  return m;
-}
-
-// generate a prefixed UID using the provided random bytes
-void vtkGeneratePrefixedUID(
-  const unsigned char *r, vtkIdType m, const char *prefix, char d,
-  char uid[64])
-{
-  size_t i = 0;
-  while (*prefix != '\0' && i < 62)
-    {
-    uid[i++] = *prefix++;
-    }
-  if (i > 0 && i < 62 && uid[i-1] != '.')
-    {
-    uid[i++] = '.';
-    }
-
-  char hexs[36];
-  vtkConvertBytesToHex(r, m, hexs);
-  char decs[40];
-  vtkConvertHexToDecimal(hexs, decs);
-
-  // generate the leading digit as the UID type
-  if (d >= '1' && d <= '9')
-    {
-    // decimal digits required to store an integer with N-1 bytes
-    static const int maxDigits[16] = {
-      3, 5, 8, 10, 13, 15, 17, 20, 22, 25, 27, 29, 32, 34, 37, 39
-    };
-
-    uid[i++] = d;
-    // add zeros so all uids will be the same length
-    size_t n = maxDigits[(m-1) & 0x0f];
-    for (size_t l = strlen(decs); l < n && i < 63; l++)
-      {
-      uid[i++] = '0';
-      }
-    }
-
-  const char *cp = decs;
-  while (i < 63 && *cp != '\0')
-    {
-    uid[i++] = *cp++;
-    }
-
-  while (i < 64)
-    {
-    uid[i++] = '\0';
-    }
-}
-
-} // end anonymous namespace
-
 //----------------------------------------------------------------------------
 std::string vtkDICOMUtilities::GenerateUID(vtkDICOMTag tag)
 {
-  const char *prefix = vtkDICOMUtilities::UIDPrefix;
-  char uid[64];
-
-  if (prefix[0] == '\0' ||
-      (prefix[0] == '2' && prefix[1] == '.' && prefix[2] == '2' &&
-       prefix[3] == '5' && (prefix[4] == '.' || prefix[4] == '\0')))
-    {
-    // generate a 128-bit random number
-    unsigned char r[16];
-    vtkGenerateRandomBytes(r, 16);
-
-    // convert to a hex uuid
-    char uuid[40];
-    vtkConvertRandomToUUID(r, uuid);
-
-    // convert the hex uuid into a DICOM UID with root 2.25
-    vtkConvertUUIDToUID(uuid, uid);
-    }
-  else
-    {
-    // after prefix, add a "UID type" digit followed by random digits
-    unsigned char r[16];
-    vtkIdType m = vtkRandomBytesForPrefix(prefix);
-    vtkGenerateRandomBytes(r, m);
-    char d = vtkDICOMTagToDigit(tag);
-    vtkGeneratePrefixedUID(r, m, prefix, d, uid);
-    }
-
-  return uid;
+  vtkDICOMUIDGenerator *uidgen = vtkDICOMUIDGenerator::GetDefault();
+  return uidgen->GenerateUID(tag);
 }
 
 //----------------------------------------------------------------------------
 void vtkDICOMUtilities::GenerateUIDs(vtkDICOMTag tag, vtkStringArray *uids)
 {
-  const char *prefix = vtkDICOMUtilities::UIDPrefix;
-
-  bool useUUIDForUID =
-    (prefix[0] == '\0' ||
-      (prefix[0] == '2' && prefix[1] == '.' && prefix[2] == '2' &&
-       prefix[3] == '5' && (prefix[4] == '.' || prefix[4] == '\0')));
-
-  vtkIdType m = 16;
-  char d = '0';
-  if (!useUUIDForUID)
-    {
-    m = vtkRandomBytesForPrefix(prefix);
-    d = vtkDICOMTagToDigit(tag);
-    }
-
-  // read from random number generator
-  vtkIdType n = uids->GetNumberOfValues();
-  unsigned char *r = new unsigned char[n*m];
-  vtkGenerateRandomBytes(r, n*m);
-
-  for (vtkIdType i = 0; i < n; i++)
-    {
-    char uid[64];
-
-    if (useUUIDForUID)
-      {
-      char uuid[40];
-      vtkConvertRandomToUUID(r + i*m, uuid);
-      vtkConvertUUIDToUID(uuid, uid);
-      }
-    else
-      {
-      vtkGeneratePrefixedUID(r + i*m, m, prefix, d, uid);
-      }
-
-    // put uids into the array in order (simple insertion sort)
-    vtkIdType j = 0;
-    for (; j < i; j++)
-      {
-      if (vtkDICOMUtilities::CompareUIDs(uids->GetValue(j), uid) > 0)
-        {
-        break;
-        }
-      }
-    for (vtkIdType k = i; k > j; --k)
-      {
-      uids->SetValue(k, uids->GetValue(k - 1));
-      }
-    uids->SetValue(j, uid);
-    }
-
-  delete [] r;
+  vtkDICOMUIDGenerator *uidgen = vtkDICOMUIDGenerator::GetDefault();
+  uidgen->GenerateUIDs(tag, uids);
 }
 
 //----------------------------------------------------------------------------
@@ -444,39 +60,39 @@ int vtkDICOMUtilities::CompareUIDs(const char *u1, const char *u2)
   int r = 0;
 
   if (u1 == 0 || u2 == 0)
-    {
+  {
     // if one or both are null
     r = (u2 == 0 ? r : -1);
     r = (u1 == 0 ? r : 1);
-    }
+  }
   else
-    {
+  {
     while (r == 0 && *u1 != 0 && *u2 != 0)
-      {
+    {
       int i1 = 0;
       int i2 = 0;
       do { i1++; } while (isdigit(u1[i1]));
       do { i2++; } while (isdigit(u2[i2]));
       r = i1 - i2; // longer number wins
       if (r == 0)
-        { // lexically compare numbers of the same length
+      { // lexically compare numbers of the same length
         do { r = *u1++ - *u2++; } while (r == 0 && --i1 != 0);
-        }
       }
+    }
 
     if (r == 0)
-      {
+    {
       // uid with remaining parts wins
       r = (*u2 == 0 ? r : -1);
       r = (*u1 == 0 ? r : 1);
-      }
+    }
     else
-      {
+    {
       // convert r to sgn(r)
       r = (r >= 0 ? r : -1);
       r = (r <= 0 ? r : 1);
-      }
     }
+  }
 
   return r;
 }
@@ -492,7 +108,7 @@ long long vtkDICOMUtilities::GetUTC(long long *offset)
                   static_cast<long long>(ft.dwLowDateTime));
 
   if (offset)
-    {
+  {
     // get the current timezone offset by subtracting UTC from local time
     TIME_ZONE_INFORMATION tzi;
     GetTimeZoneInformation(&tzi);
@@ -506,15 +122,15 @@ long long vtkDICOMUtilities::GetUTC(long long *offset)
     long long tzo = ((static_cast<long long>(lft.dwHighDateTime) << 32) +
                      static_cast<long long>(lft.dwLowDateTime) - t1);
     if (tzo >= 0)
-      {
+    {
       tzo = (tzo + 5000000)/10000000;
-      }
-    else
-      {
-      tzo = -((-tzo + 5000000)/10000000);
-      }
-    *offset = tzo*1000000;
     }
+    else
+    {
+      tzo = -((-tzo + 5000000)/10000000);
+    }
+    *offset = tzo*1000000;
+  }
 
   // convert file time to unix time
   return t1/10 - 11644473600000000ll;
@@ -525,21 +141,21 @@ long long vtkDICOMUtilities::GetUTC(long long *offset)
   gettimeofday(&tv, 0);
   long long t = (tv.tv_sec*1000000ll + tv.tv_usec);
   if (offset)
-    {
+  {
     static long long lastT = 0;
     if (t - lastT > 1000000ll)
-      {
+    {
       // this is needed on some systems to set timezone info,
       // because it might do I/O do it at most once per second
       tzset();
       lastT = t;
-      }
+    }
     // use localtime to get the offset from utc
     struct tm tmv;
     time_t tod = static_cast<time_t>(t/1000000);
     localtime_r(&tod, &tmv);
     *offset = tmv.tm_gmtoff*1000000ll;
-    }
+  }
 
   return t;
 
@@ -564,32 +180,32 @@ std::string vtkDICOMUtilities::GenerateDateTime(
   // all time stamps for the data set
   if (z && strlen(z) == 5 && (z[0] == '+' || z[0] == '-') &&
       isdigit(z[1]) && isdigit(z[2]) && isdigit(z[3]) && isdigit(z[4]))
-    {
+  {
     int zh = (z[1] - '0')*10 + (z[2] - '0');
     int zm = (z[3] - '0')*10 + (z[4] - '0');
     zs = (zh*3600 + zm*60) * (z[0] == '-' ? -1 : +1) * 1000000ll;
-    }
+  }
 
   if (z == 0 || z[0] == '\0' || t == VTK_LONG_LONG_MIN)
-    {
+  {
     long long *zsp = 0;
     if (z == 0 || z[0] == '\0')
-      {
+    {
       zsp = &zs;
-      }
+    }
 
     long long t1 = vtkDICOMUtilities::GetUTC(zsp);
 
     if (t == VTK_LONG_LONG_MIN)
-      {
+    {
       t = t1;
-      }
     }
+  }
 
   // generate a new timezone offset string
   char tzs[6] = { '+', '0', '0', '0', '0', '\0' };
   if (z == 0 || z[0] == '\0')
-    {
+  {
     long long zst = zs/1000000;
     tzs[0] = (zst < 0 ? '-' : '+');
     zst = (zst < 0 ? -zst : zst);
@@ -597,7 +213,7 @@ std::string vtkDICOMUtilities::GenerateDateTime(
             static_cast<int>((zst/3600)%24),
             static_cast<int>((zst%3600)/60));
     z = tzs;
-    }
+  }
 
   // add the time zone offset (in microseconds)
   t += zs;
@@ -619,9 +235,9 @@ std::string vtkDICOMUtilities::GenerateDateTime(
   int m = j + 2 - (12 * ell);
   int y = 100 * (n - 49) + i + ell;
   if (y > 9999)
-    {
+  {
     y = 9999;
-    }
+  }
 
   // convert microseconds to hours/minutes/seconds.microseconds
   int S = static_cast<int>(tus/1000000);
@@ -646,34 +262,34 @@ long long vtkDICOMUtilities::ConvertDateTime(const char *datetime)
   const char *epoch = "19700101000000.000000+0000";
   char normalized[27];
   for (int i = 0; i < 27; i++)
-    {
+  {
     normalized[i] = epoch[i];
-    }
+  }
   char *tp = normalized;
   const char *cp = datetime;
   while (*tp != 0 && *cp >= '0' && *cp <= '9')
-    {
+  {
     *tp++ = *cp++;
-    }
+  }
   if (*tp == '.' && *cp == '.')
-    {
+  {
     *tp++ = *cp++;
     while (*tp != 0 && *cp >= '0' && *cp <= '9')
-      {
-      *tp++ = *cp++;
-      }
-    }
-  if (*cp == '-' || *cp == '+')
     {
+      *tp++ = *cp++;
+    }
+  }
+  if (*cp == '-' || *cp == '+')
+  {
     tp = normalized + 21;
     *tp++ = *cp++;
     while (*tp != 0 && *cp >= '0' && *cp <= '9')
-      {
-      *tp++ = *cp++;
-      }
-    }
-  else
     {
+      *tp++ = *cp++;
+    }
+  }
+  else
+  {
     // use local time zone
     long long offset = 0;
     vtkDICOMUtilities::GetUTC(&offset);
@@ -689,7 +305,7 @@ long long vtkDICOMUtilities::ConvertDateTime(const char *datetime)
     tp[3] = M/10 + '0';
     tp[4] = M%10 + '0';
     tp[5] = 0;
-    }
+  }
 
   // convert normalized datetime to year, month, day etc.
   // first, convert all digits (and only digits) to binary values
@@ -697,9 +313,9 @@ long long vtkDICOMUtilities::ConvertDateTime(const char *datetime)
   normalized[14] += '0';
   normalized[21] += '0';
   for (int i = 0; i < 26; i++)
-    {
+  {
     normalized[i] -= '0';
-    }
+  }
 
   int y = tp[0]*1000 + tp[1]*100 + tp[2]*10 + tp[3];
   int m = tp[4]*10 + tp[5];
@@ -713,9 +329,9 @@ long long vtkDICOMUtilities::ConvertDateTime(const char *datetime)
   // get the timezone offset, in seconds
   int tzs = (tp[22]*600 + tp[23]*60 + tp[24]*10 + tp[25])*60;
   if (tp[21] == '-')
-    {
+  {
     tzs = -tzs;
-    }
+  }
 
   // use algorithm from Henry F. Fliegel and Thomas C. Van Flandern
   // to compute the day according to Gregorian calendar
@@ -738,73 +354,82 @@ bool vtkDICOMUtilities::IsDICOMFile(const char *filename)
   unsigned char buffer[256];
 
   if (filename == 0)
-    {
+  {
     return false;
-    }
+  }
 
   vtkDICOMFile infile(filename, vtkDICOMFile::In);
 
   if (infile.GetError() != 0)
-    {
+  {
     return false;
-    }
+  }
 
   // valid file should be at least 256 chars long (probably longer)
   size_t size = infile.GetSize();
   if (size < sizeof(buffer))
-    {
+  {
     return 0;
-    }
+  }
   size = sizeof(buffer);
 
   size_t rsize = infile.Read(buffer, size);
   infile.Close();
   if (rsize != static_cast<size_t>(size))
-    {
+  {
     return false;
-    }
+  }
 
   const unsigned char *cp = buffer;
 
   // Look for the magic number and the first meta header tag.
   size_t skip = 128;
   for (int i = 0; i < 2; i++)
-    {
+  {
     if (size > skip + 8)
-      {
+    {
       cp = &buffer[skip];
       if (cp[0] == 'D' && cp[1] == 'I' && cp[2] == 'C' && cp[3] == 'M' &&
           cp[4] == 2 && cp[5] == 0 && cp[6] == 0 && cp[7] == 0)
-        {
+      {
         return true;
-        }
       }
+    }
     // Some non-standard files have DICM at the beginning.
     skip = 0;
-    }
+  }
 
   // File must be a reasonable size.
   if (size < 256)
-    {
+  {
     return false;
-    }
+  }
 
   cp = buffer;
 
   // If no magic number found, look for a valid meta header.
   if (cp[0] == 2 && cp[1] == 0 && cp[2] == 0 && cp[3] == 0 &&
       cp[4] == 'U' && cp[5] == 'L' && cp[6] == 4 && cp[7] == 0)
-    {
+  {
     return true;
-    }
+  }
 
-  // Finally, look for little-endian implicit ACR-NEMA.
-  if (cp[0] == 8 && cp[1] == 0 && cp[2] == 0 && cp[3] == 0 &&
-      cp[4] == 4 && cp[5] == 0 && cp[6] == 0 && cp[7] == 0 &&
-      cp[12] == 8 && cp[13] == 0 && (cp[14] != 0 || cp[15] != 0))
+  // Look for two valid implicitly-encoded data elements in Group 0x0008,
+  // where the first element must be (0008,0016) or less (e.g. SOPClassUID)
+  // with a size of 64 or less, and the second element must be (0008,0018)
+  // or less (e.g. SOPInstanceUID) with a size of 64 or less.
+  if (cp[0] == 0x08 && cp[1] == 0x00 && cp[2] <= 0x16 && cp[3] == 0x00 &&
+      cp[4] <= 0x40 && cp[5] == 0x00 && cp[6] == 0x00 && cp[7] == 0x00)
+  {
+    unsigned char e = cp[2];
+    cp += (cp[4] + 8);
+    if (cp[0] == 0x08 && cp[1] == 0x00 && cp[2] <= 0x18 && cp[3] == 0x00 &&
+        cp[4] <= 0x40 && cp[5] == 0x00 && cp[6] == 0x00 && cp[7] == 0x00 &&
+        cp[2] > e)
     {
-    return true;
+      return true;
     }
+  }
 
   return false;
 }
@@ -880,79 +505,79 @@ bool vtkDICOMUtilities::PatternMatches(
   const char *fp = val + vl;
 
   while (cp != ep && dp != fp)
-    {
+  {
     if (*cp == '*')
-      {
+    {
       cp++;
       // if '*' is the final character, it matches the remainder of val
       if (cp == ep)
-        {
+      {
         dp = fp;
-        }
+      }
       else
-        {
+      {
         while (dp != fp)
-          {
+        {
           if (*cp == '?' || *dp == *cp)
-            {
+          {
             // check if the remainder of val matches remainder of pattern
             if (PatternMatches(cp, ep-cp, dp, fp-dp))
-              {
+            {
               break;
-              }
             }
+          }
           // else let the "*" eat one more codepoint of "val"
           if (static_cast<signed char>(*dp++) < 0)
-            {
+          {
             while (dp != fp && (*dp & 0xC0) == 0x80)
-              {
+            {
               dp++;
-              }
             }
           }
         }
       }
+    }
     else if (*cp == '?')
-      {
+    {
       // the '?' matches a whole codepoint, not just one byte
       cp++;
       if (static_cast<signed char>(*dp++) < 0)
-        {
+      {
         while (dp != fp && (*dp & 0xC0) == 0x80)
-          {
+        {
           dp++;
-          }
         }
       }
+    }
     else if (*cp == *dp)
-      {
+    {
       // make sure the entire codepoint matches
       cp++;
       if (static_cast<signed char>(*dp++) < 0)
-        {
+      {
         while (cp != ep && dp != fp &&
                ((*cp & 0xC0) == 0x80 || (*dp & 0xC0) == 0x80))
-          {
+        {
           if (*dp != *cp)
-            {
+          {
             return false;
-            }
+          }
           cp++;
           dp++;
-          }
         }
       }
-    else
-      {
-      return false;
-      }
     }
+    else
+    {
+      return false;
+    }
+  }
 
   // skip over any remaining '*' wildcards
   while (cp != ep && *cp == '*')
-    {
+  {
     cp++;
-    }
+  }
 
   // make sure we've reached the end of both the pattern and the value
   return (cp == ep && dp == fp);
