@@ -86,10 +86,7 @@ vtkNIFTIWriter::vtkNIFTIWriter()
   this->OwnHeader = 0;
   this->NIFTIHeader = 0;
   this->NIFTIVersion = 0;
-  this->Description = new char[80];
-  // Default description is "VTKX.Y.Z"
-  strncpy(this->Description, "VTK", 3);
-  strncpy(&this->Description[3], vtkVersion::GetVTKVersion(), 77);
+  this->Description = 0;
   // Planar RGB (NIFTI doesn't allow this, it's here for Analyze)
   this->PlanarRGB = false;
 }
@@ -98,21 +95,21 @@ vtkNIFTIWriter::vtkNIFTIWriter()
 vtkNIFTIWriter::~vtkNIFTIWriter()
 {
   if (this->QFormMatrix)
-    {
+  {
     this->QFormMatrix->Delete();
-    }
+  }
   if (this->SFormMatrix)
-    {
+  {
     this->SFormMatrix->Delete();
-    }
+  }
   if (this->OwnHeader)
-    {
+  {
     this->OwnHeader->Delete();
-    }
+  }
   if (this->NIFTIHeader)
-    {
+  {
     this->NIFTIHeader->Delete();
-    }
+  }
   delete [] this->Description;
 }
 
@@ -120,9 +117,9 @@ vtkNIFTIWriter::~vtkNIFTIWriter()
 vtkNIFTIHeader *vtkNIFTIWriter::GetNIFTIHeader()
 {
   if (!this->NIFTIHeader)
-    {
+  {
     this->NIFTIHeader = vtkNIFTIHeader::New();
-    }
+  }
   return this->NIFTIHeader;
 }
 
@@ -131,7 +128,8 @@ void vtkNIFTIWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "Description: " << this->Description << "\n";
+  os << indent << "Description: "
+     << (this->Description ? this->Description : "(NULL)") << "\n";
   os << indent << "TimeDimension: " << this->TimeDimension << "\n";
   os << indent << "TimeSpacing: " << this->TimeSpacing << "\n";
   os << indent << "RescaleSlope: " << this->RescaleSlope << "\n";
@@ -140,35 +138,35 @@ void vtkNIFTIWriter::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "QFormMatrix:";
   if (this->QFormMatrix)
-    {
+  {
     double mat[16];
     vtkMatrix4x4::DeepCopy(mat, this->QFormMatrix);
     for (int i = 0; i < 16; i++)
-      {
-      os << " " << mat[i];
-      }
-    os << "\n";
-    }
-  else
     {
-    os << " (none)\n";
+      os << " " << mat[i];
     }
+    os << "\n";
+  }
+  else
+  {
+    os << " (none)\n";
+  }
 
   os << indent << "SFormMatrix:";
   if (this->SFormMatrix)
-    {
+  {
     double mat[16];
     vtkMatrix4x4::DeepCopy(mat, this->SFormMatrix);
     for (int i = 0; i < 16; i++)
-      {
-      os << " " << mat[i];
-      }
-    os << "\n";
-    }
-  else
     {
-    os << " (none)\n";
+      os << " " << mat[i];
     }
+    os << "\n";
+  }
+  else
+  {
+    os << " (none)\n";
+  }
 
   os << indent << "NIFTIHeader:" << (this->NIFTIHeader ? "\n" : " (none)\n");
   os << indent << "NIFTIVersion: " << this->NIFTIVersion << "\n";
@@ -187,27 +185,27 @@ char *vtkNIFTIWriter::ReplaceExtension(
   if (n > 2 && filename[n-3] == '.' &&
       tolower(filename[n-2]) == 'g' &&
       tolower(filename[n-1]) == 'z')
-    {
+  {
     m -= 3;
-    }
+  }
   if (m > 3 && filename[m-4] == '.' &&
       tolower(filename[m-3]) == tolower(ext1[1]) &&
       tolower(filename[m-2]) == tolower(ext1[2]) &&
       tolower(filename[m-1]) == tolower(ext1[3]))
-    {
+  {
     if (isupper(filename[m-3]))
-      {
+    {
       newname[m-3] = toupper(ext2[1]);
       newname[m-2] = toupper(ext2[2]);
       newname[m-1] = toupper(ext2[3]);
-      }
+    }
     else
-      {
+    {
       newname[m-3] = tolower(ext2[1]);
       newname[m-2] = tolower(ext2[2]);
       newname[m-1] = tolower(ext2[3]);
-      }
     }
+  }
 
   return newname;
 }
@@ -290,14 +288,14 @@ void vtkNIFTIWriterSetInformation(
   short databits = 0;
 
   for (int i = 0; typeMap[2] != 0; i++)
-    {
+  {
     if (scalarType == typeMap[i][0])
-      {
+    {
       datatype = typeMap[i][1];
       databits = typeMap[i][2];
       break;
-      }
     }
+  }
 
   // number of spatial dimensions
   int spaceDim = (extent[4] == extent[5] ? 2 : 3);
@@ -343,22 +341,22 @@ void vtkNIFTIWriterSetQForm(
   double quat[4];
   vtkMath::Matrix3x3ToQuaternion(rmat, quat);
   if (quat[0] < 0)
-    {
+  {
     quat[0] = -quat[0];
     quat[1] = -quat[1];
     quat[2] = -quat[2];
     quat[3] = -quat[3];
-    }
+  }
 
   if (qfac < 0)
-    {
+  {
     // We will be reversing the order of the slices, so the first VTK
     // slice will be at the position of the last NIfTI slice, and we
     // must adjust the offset to compensate for this.
     mmat[3] += rmat[0][2]*hdr->pixdim[3]*(hdr->dim[3] - 1);
     mmat[7] += rmat[1][2]*hdr->pixdim[3]*(hdr->dim[3] - 1);
     mmat[11] += rmat[2][2]*hdr->pixdim[3]*(hdr->dim[3] - 1);
-    }
+  }
 
   hdr->pixdim[0] = qfac;
   hdr->quatern_b = quat[1];
@@ -374,7 +372,7 @@ void vtkNIFTIWriterSetSForm(
   nifti_2_header *hdr, double mmat[16], double qfac)
 {
   if (qfac < 0)
-    {
+  {
     // If QFac is set to -1 (which only occurs if qform_code was set)
     // then the slices will be reversed, and we must reverse the slice
     // orientation vector (the third column of the matrix) to compensate.
@@ -388,7 +386,7 @@ void vtkNIFTIWriterSetSForm(
     mmat[2] = -mmat[2];
     mmat[6] = -mmat[6];
     mmat[10] = -mmat[10];
-    }
+  }
 
   // first row
   hdr->srow_x[0] = mmat[0] * hdr->pixdim[1];
@@ -420,14 +418,14 @@ void vtkNIFTIWriterMatrix(
   offset[3] = 1.0;
 
   if (matrix)
-    {
+  {
     matrix->MultiplyPoint(offset, offset);
     vtkMatrix4x4::DeepCopy(mmat, matrix);
-    }
+  }
   else
-    {
+  {
     vtkMatrix4x4::Identity(mmat);
-    }
+  }
 
   mmat[3] = offset[0];
   mmat[7] = offset[1];
@@ -443,50 +441,50 @@ int vtkNIFTIWriter::GenerateHeader(vtkInformation *info, bool singleFile)
   nifti_2_header hdr;
   int version = 0;
   if (this->OwnHeader == 0)
-    {
+  {
     this->OwnHeader = vtkNIFTIHeader::New();
-    }
+  }
   else
-    {
+  {
     this->OwnHeader->Initialize();
-    }
+  }
   if (this->NIFTIHeader)
-    {
+  {
     // use the header supplied by SetNIFTIHeader()
     this->NIFTIHeader->GetHeader(&hdr);
     version = hdr.magic[2] - '0';
     if (version > 2)
-      {
-      version = 2;
-      }
-    }
-  else
     {
+      version = 2;
+    }
+  }
+  else
+  {
     // start with a blank header
     this->OwnHeader->GetHeader(&hdr);
     hdr.scl_slope = 1.0;
-    }
+  }
 
   // copy the image information into the header
   vtkNIFTIWriterSetInformation(&hdr, info);
   if (hdr.datatype == 0)
-    {
+  {
     vtkErrorMacro("Illegal data type for NIFTI file.");
     return 0;
-    }
+  }
 
   // override the version if set via SetNIFTIVersion
   if (this->NIFTIVersion != 0)
-    {
+  {
     version = this->NIFTIVersion;
-    }
+  }
 
   // set the rescale slope/intercept if not (0.0,0.0)
   if (this->RescaleSlope != 0.0 || this->RescaleIntercept != 0.0)
-    {
+  {
     hdr.scl_slope = this->RescaleSlope;
     hdr.scl_inter = this->RescaleIntercept;
-    }
+  }
 
   // set the header size
   hdr.sizeof_hdr = (version == 2 ?
@@ -495,27 +493,27 @@ int vtkNIFTIWriter::GenerateHeader(vtkInformation *info, bool singleFile)
 
   // modify magic number and voxel offset for .img files
   if (!singleFile)
-    {
+  {
     strncpy(hdr.magic, (version == 2 ? "ni2" : "ni1"), 4);
     hdr.vox_offset = 0;
-    }
+  }
   else
-    {
+  {
     strncpy(hdr.magic, (version == 2 ? "n+2" : "n+1"), 4);
     hdr.vox_offset = (version == 2 ? 544 : 352);
-    }
+  }
   if (version == 2)
-    {
+  {
     // version 2 has four bytes for newline transfer checks
     strncpy(&hdr.magic[4], "\r\n\032\n", 4);
-    }
+  }
 
   // set the description
   if (this->Description)
-    {
+  {
     strncpy(hdr.descrip, this->Description, sizeof(hdr.descrip) - 1);
     hdr.descrip[sizeof(hdr.descrip) - 1] = '\0';
-    }
+  }
 
   // qfac dictates the slice ordering in the file
   double qfac = (this->QFac < 0 ? -1.0 : 1.0);
@@ -526,72 +524,72 @@ int vtkNIFTIWriter::GenerateHeader(vtkInformation *info, bool singleFile)
 
   if (this->QFormMatrix ||
       (origin[0] != 0 || origin[1] != 0 || origin[2] != 0))
-    {
+  {
     hdr.qform_code = 1; // SCANNER_ANAT
     double mat16[16];
     vtkNIFTIWriterMatrix(mat16, this->QFormMatrix, origin);
     vtkNIFTIWriterSetQForm(&hdr, mat16, qfac);
-    }
+  }
 
   if (this->SFormMatrix)
-    {
+  {
     hdr.sform_code = 2; // ALIGNED_ANAT
     double mat16[16];
     vtkNIFTIWriterMatrix(mat16, this->SFormMatrix, origin);
     vtkNIFTIWriterSetSForm(&hdr, mat16, qfac);
-    }
+  }
 
   // base dimension not counting vector dimension
   int basedim = (hdr.dim[3] == 1 ? 2 : 3);
 
   if (this->TimeDimension)
-    {
+  {
     int tdim = this->TimeDimension;
     if (hdr.dim[5] % tdim != 0)
-      {
+    {
       vtkErrorMacro("Number of components in the image data must be "
                     "divisible by the TimeDimension");
       return 0;
-      }
+    }
     hdr.pixdim[4] = this->TimeSpacing;
     hdr.dim[4] = tdim;
     hdr.dim[5] /= tdim;
     hdr.dim[0] = (hdr.dim[5] > 1 ? 5 : 4);
     basedim = 4;
-    }
+  }
 
   if (hdr.dim[5] == 2 && hdr.datatype == NIFTI_TYPE_FLOAT32)
-    {
+  {
     // float with 2 components becomes COMPLEX64
     hdr.datatype = NIFTI_TYPE_COMPLEX64;
     hdr.bitpix = 64;
     hdr.dim[0] = basedim;
     hdr.dim[5] = 1;
-    }
+  }
   else if (hdr.dim[5] == 2 && hdr.datatype == NIFTI_TYPE_FLOAT64)
-    {
+  {
     // double with 2 components becomes COMPLEX128
     hdr.datatype = NIFTI_TYPE_COMPLEX128;
     hdr.bitpix = 32;
     hdr.dim[0] = basedim;
     hdr.dim[5] = 1;
-    }
+  }
   else if (hdr.dim[5] == 3 && hdr.datatype == NIFTI_TYPE_UINT8)
-    {
+  {
     // unsigned char with 3 components becomes RGB24
     hdr.datatype = NIFTI_TYPE_RGB24;
     hdr.bitpix = 24;
     hdr.dim[0] = basedim;
     hdr.dim[5] = 1;
-    }
+  }
   else if (hdr.dim[5] == 4 && hdr.datatype == NIFTI_TYPE_UINT8)
-    {
+  {
     // unsigned char with 4 components becomes RGBA32
     hdr.datatype = NIFTI_TYPE_RGBA32;
     hdr.bitpix = 32;
     hdr.dim[0] = basedim;
     hdr.dim[5] = 1;
-    }
+  }
 
   this->OwnHeader->SetHeader(&hdr);
   return 1;
@@ -610,18 +608,18 @@ int vtkNIFTIWriter::RequestData(
     vtkImageData::SafeDownCast(info->Get(vtkDataObject::DATA_OBJECT()));
 
   if (data == NULL)
-    {
+  {
     vtkErrorMacro("No input provided!");
     return 0;
-    }
+  }
 
   const char *filename = this->GetFileName();
   if (filename == NULL)
-    {
+  {
     vtkErrorMacro("A FileName must be provided");
     this->SetErrorCode(vtkErrorCode::NoFileNameError);
     return 0;
-    }
+  }
 
   int extent[6];
   info->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), extent);
@@ -633,10 +631,10 @@ int vtkNIFTIWriter::RequestData(
   if (n > 2 && filename[n-3] == '.' &&
       tolower(filename[n-2]) == 'g' &&
       tolower(filename[n-1]) == 'z')
-    {
+  {
     m = n - 3;
     isCompressed = true;
-    }
+  }
 
   // after the optional ".gz" is removed, is it a ".img/.hdr" file?
   bool singleFile = true;
@@ -647,15 +645,15 @@ int vtkNIFTIWriter::RequestData(
        (tolower(filename[m-3]) == 'i' &&
         tolower(filename[m-2]) == 'm' &&
         tolower(filename[m-1]) == 'g')))
-    {
+  {
     singleFile = false;
-    }
+  }
 
   // generate the header information
   if (this->GenerateHeader(info, singleFile) == 0)
-    {
+  {
     return 0;
-    }
+  }
 
   // if file is not .nii, then get .hdr and .img filenames
   char *hdrname = vtkNIFTIWriter::ReplaceExtension(
@@ -672,26 +670,26 @@ int vtkNIFTIWriter::RequestData(
   size_t hdrsize = 0;
   int version = this->OwnHeader->GetMagic()[2] - '0';
   if (version == 2)
-    {
+  {
     this->OwnHeader->GetHeader(&hdr2);
     hdrptr = &hdr2;
     hdrsize = hdr2.sizeof_hdr;
-    }
+  }
   else
-    {
+  {
     this->OwnHeader->GetHeader(&hdr1);
     hdrptr = &hdr1;
     hdrsize = hdr1.sizeof_hdr;
     if (extent[1] - extent[0] + 1 > VTK_SHORT_MAX ||
         extent[3] - extent[2] + 1 > VTK_SHORT_MAX ||
         extent[5] - extent[4] + 1 > VTK_SHORT_MAX)
-      {
+    {
       vtkErrorMacro("Image too large to store in NIFTI-1 format");
       return 0;
-      }
     }
+  }
 
-#if _WIN32 
+#if _WIN32
   vtkDICOMFilePath fph(hdrname);
   vtkDICOMFilePath fpi(imgname);
 #if VTK_MAJOR_VERSION < 7
@@ -712,24 +710,24 @@ int vtkNIFTIWriter::RequestData(
   gzFile file = 0;
   FILE *ufile = 0;
   if (uhdrname && uimgname)
-    {
+  {
     if (isCompressed)
-      {
+    {
       file = gzopen(uhdrname, "wb");
-      }
-    else
-      {
-      ufile = fopen(uhdrname, NIFTI_FILE_MODE);
-      }
     }
+    else
+    {
+      ufile = fopen(uhdrname, NIFTI_FILE_MODE);
+    }
+  }
 
   if (!file && !ufile)
-    {
+  {
     delete [] hdrname;
     delete [] imgname;
     this->SetErrorCode(vtkErrorCode::CannotOpenFileError);
     return 0;
-    }
+  }
 
   this->InvokeEvent(vtkCommand::StartEvent);
   this->UpdateProgress(0.0);
@@ -737,62 +735,62 @@ int vtkNIFTIWriter::RequestData(
   // write the header
   size_t bytesWritten = 0;
   if (isCompressed)
-    {
+  {
     unsigned int hsize = static_cast<unsigned int>(hdrsize);
     int code = gzwrite(file, hdrptr, hsize);
     bytesWritten = (code < 0 ? 0 : code);
-    }
+  }
   else
-    {
+  {
     bytesWritten = fwrite(hdrptr, 1, hdrsize, ufile);
-    }
+  }
   if (bytesWritten < hdrsize)
-    {
+  {
     this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
-    }
+  }
 
   if (singleFile && !this->ErrorCode)
-    {
+  {
     // write the padding between the header and the image to the .nii file
     size_t padsize = (static_cast<size_t>(this->OwnHeader->GetVoxOffset()) -
                       hdrsize);
     char *padding = new char[padsize];
     memset(padding, '\0', padsize);
     if (isCompressed)
-      {
+    {
       int code = gzwrite(file, padding, static_cast<unsigned int>(padsize));
       bytesWritten = (code < 0 ? 0 : code);
-      }
+    }
     else
-      {
+    {
       bytesWritten = fwrite(padding, 1, padsize, ufile);
-      }
+    }
     delete [] padding;
     if (bytesWritten < padsize)
-      {
-      this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
-      }
-    }
-  else if (!this->ErrorCode)
     {
+      this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
+    }
+  }
+  else if (!this->ErrorCode)
+  {
     // close the .hdr file and open the .img file
     if (isCompressed)
-      {
+    {
       gzclose(file);
       file = gzopen(uimgname, "wb");
-      }
+    }
     else
-      {
+    {
       fclose(ufile);
       ufile = fopen(uimgname, NIFTI_FILE_MODE);
-      }
     }
+  }
 
   if (!file && !ufile)
-    {
+  {
     vtkErrorMacro("Cannot open file " << imgname);
     this->SetErrorCode(vtkErrorCode::CannotOpenFileError);
-    }
+  }
 
   // write the image
   unsigned char *dataPtr =
@@ -818,41 +816,41 @@ int vtkNIFTIWriter::RequestData(
   z_off_t fileVoxelIncr = scalarSize*numComponents/vectorDim;
   int planarSize = 1;
   if (planarRGB)
-    {
+  {
     planarSize = numComponents/vectorDim;
     fileVoxelIncr = scalarSize;
-    }
+  }
 
   // add a buffer for planar-vector to packed-vector conversion
   unsigned char *rowBuffer = 0;
   if (vectorDim > 1 || planarRGB || swapBytes)
-    {
+  {
     rowBuffer = new unsigned char[outSizeX*fileVoxelIncr];
-    }
+  }
 
   // special increment to reverse the slices if needed
   vtkIdType sliceOffset = 0;
 
   if (this->QFac < 0)
-    {
+  {
     // put slices in reverse order
     sliceOffset = scalarSize*numComponents;
     sliceOffset *= outSizeX;
     sliceOffset *= outSizeY;
     dataPtr += sliceOffset*(outSizeZ - 1);
-    }
+  }
 
   // special increment to handle planar RGB
   vtkIdType planarOffset = 0;
   vtkIdType planarEndOffset = 0;
   if (planarRGB)
-    {
+  {
     planarOffset = scalarSize*numComponents;
     planarOffset *= outSizeX;
     planarOffset *= outSizeY;
     planarOffset -= scalarSize;
     planarEndOffset = planarOffset - scalarSize*(planarSize - 1);
-    }
+  }
 
   // report progress every 2% of the way to completion
   vtkIdType target =
@@ -871,115 +869,115 @@ int vtkNIFTIWriter::RequestData(
   unsigned char *ptr = dataPtr;
 
   while (!this->AbortExecute && !this->ErrorCode)
-    {
+  {
     if (vectorDim == 1 && !planarRGB && !swapBytes)
-      {
+    {
       // write directly from input, instead of using a buffer
       rowBuffer = ptr;
       ptr += outSizeX*numComponents*scalarSize;
-      }
+    }
     else
-      {
+    {
       // create a vector plane from packed vector components
       unsigned char *tmpPtr = rowBuffer;
       z_off_t skipOther = scalarSize*numComponents - fileVoxelIncr;
       for (int i = 0; i < outSizeX; i++)
-        {
+      {
         // write one vector component of one voxel
         z_off_t nn = fileVoxelIncr;
         do { *tmpPtr++ = *ptr++; } while (--nn);
         // skip past the other components
         ptr += skipOther;
-        }
       }
+    }
 
     if (swapBytes != 0 && scalarSize > 1)
-      {
+    {
       vtkByteSwap::SwapVoidRange(rowBuffer, rowSize, scalarSize);
-      }
+    }
 
     if (isCompressed)
-      {
+    {
       int code = gzwrite(file, rowBuffer, rowSize*scalarSize);
       bytesWritten = (code < 0 ? 0 : code);
-      }
+    }
     else
-      {
+    {
       bytesWritten = fwrite(rowBuffer, scalarSize, rowSize, ufile)*scalarSize;
-      }
+    }
     if (bytesWritten < static_cast<size_t>(rowSize*scalarSize))
-      {
+    {
       this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
       break;
-      }
+    }
 
     if (++count % target == 0)
-      {
+    {
       this->UpdateProgress(0.02*count/target);
-      }
+    }
 
     if (++j == outSizeY)
-      {
+    {
       j = 0;
       // back up for next plane (R, G, or B) if planar mode
       ptr -= planarOffset;
       if (++p == planarSize)
-        {
+      {
         p = 0;
         ptr += planarEndOffset; // advance to start of next slice
         ptr -= 2*sliceOffset; // for reverse slice order
         if (++k == outSizeZ)
-          {
+        {
           k = 0;
           if (++t == timeDim)
-            {
+          {
             t = 0;
-            }
+          }
           if (++c == vectorDim)
-            {
+          {
             break;
-            }
+          }
           // back up the ptr to the beginning of the image,
           // then increment to the next vector component
           ptr = dataPtr + c*fileVoxelIncr*planarSize;
 
           if (timeDim > 1)
-            {
+          {
             // if timeDim is included in the vectorDim (and hence in the
             // VTK scalar components) then we have to make sure that
             // the vector components are packed before the time steps
             ptr = dataPtr + (c + t*(vectorDim - 1))/timeDim*
                              fileVoxelIncr*planarSize;
-            }
           }
         }
       }
     }
+  }
 
   if (vectorDim > 1 || swapBytes || planarRGB)
-    {
+  {
     delete [] rowBuffer;
-    }
+  }
 
   if (isCompressed)
-    {
+  {
     gzclose(file);
-    }
+  }
   else
-    {
+  {
     fclose(ufile);
-    }
+  }
 
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     // erase the file, rather than leave a corrupt file on disk
     vtkErrorMacro("Out of disk space, removing incomplete file " << imgname);
     vtkDICOMFile::Remove(imgname);
     if (!singleFile)
-      {
+    {
       vtkDICOMFile::Remove(hdrname);
-      }
     }
+  }
 
   this->UpdateProgress(1.0);
   this->InvokeEvent(vtkCommand::EndEvent);
